require.config({
  paths: {
	handlebars: 'js/lib/handlebars',
	text: 'js/lib/text',
	hbs: 'js/hbs',
	jquery: 'js/jquery-3.1.1.min'
  },
  shim: {
	handlebars: {
      exports: 'Handlebars'
	}
  }
});

define('app', [
  'jquery',
  'js/config',
  'js/lib/pawebjs',
  'js/jsencrypt',
  'js/datas',
  'js/polyfill'
], function(
	$$,
	config,
	PaWebJs,
	JSEncryptObj,
	Datas
) {
	var host = config.host;
	var baseHost = config.baseHost;
	var appVersion = config.appVersion;
	var RsaPublicKey = config.RsaPublicKey;
	var SKIP = config.SKIP;
	var JSEncrypt = JSEncryptObj.JSEncrypt;
	var $ = Framework7.$;
	var dictData = Datas.dictData;
	var timeCountData = Datas.timeCountData;
	
	// 请求参数，版本信息， 在下部分发请求会用到
	var version = JSON.parse(localStorage.getItem('version'));  
	// sparta webJS
	var fp = new PaWebJs().get();
	
	if (!SKIP.cordova_inAppBrowserOpen) {
		window.jumpLink = cordova.InAppBrowser.open;
	} else {
		window.jumpLink = window.open;
	}

	function getDeviceType() {
		var deviceType = '';
		var ua = navigator.userAgent.toLowerCase();

		if (/iphone|ipad|ipod/.test(ua)) {
			deviceType = 'IOS';
		} else if (/android/.test(ua)) {
			deviceType = 'ANDROID';
		} else {
			// 默认值为'ANDROID', 后端默认值为'ANDROID'
			deviceType = 'ANDROID';
		}

		return deviceType;
	}
	
    $(document).on('pageBeforeInit', function(e) {
    	var page = e.detail.page;
    	
    	if (/^appliance/.test(page.name)) {
    		loadApplianceContainer(page.name, page.query);
    	}else if (/^education/.test(page.name)) {
			loadEducationContainer(page.name, page.query);	
    	}else if (/^adultEducation/.test(page.name)) {
    		loadAdultEducationContainer(page.name, page.query);
    	}else if (/^advanceCredit/.test(page.name)) {
    		loadAdvanceCreditContainer(page.name, page.query);
    	}else if (/^familyDecorationOnline/.test(page.name)) {
    		loadFamilyDecorationOnlineContainer(page.name, page.query);
    	}else if (/^familyDecoration/.test(page.name)) {
    		loadFamilyDecorationContainer(page.name, page.query);
    	}else if (/^medicalCare/.test(page.name)) {
    		loadMedicalCareContainer(page.name, page.query);
    	}else if (/^employeeBuy/.test(page.name)) {
    		loadEmployeeBuyContainer(page.name, page.query);
    	}else if (page.name !== '0_index' && page.name !== '1_index' && page.name !== '2_index') {
        	loadContainer(page.name, page.query);
        }
    });

	f7 = new Framework7({
		animateNavBackIcon : true,
		modalCloseByOutside : false,
		actionsCloseByOutside : false,
		popupCloseByOutside : false,
		swipeBackPage: false,					// 禁用右滑返回操作
//		dynamicNavbar: true
//		pushState: true,
//		pushStateSeparator: '',
//		pushStateNoAnimation: true,
		imagesLazyLoadPlaceholder: 'img/employeeBuy/placeholder/goods-placeholder.jpg',
		onPageInit: function(app, page) {
			// 清除员工购首页的定时器
			if (
					page.name == 'employeeBuyAuthenticationSupplement' ||
					page.name == 'employeeBuyGoodsDetail' || 
					page.name == 'employeeBuyUploadIdCard' || 
					page.name == 'index' ||
					page.name == 'employeeBuyGoodsActivity'
			) {
				if (Array.isArray(timeCountData.employeeBuyIndexTimeCount) && timeCountData.employeeBuyIndexTimeCount.length > 0) {
					timeCountData.employeeBuyIndexTimeCount.forEach(function(item) {
						clearInterval(item);
					});
				}
			}
		}
	});

	mainView = f7.addView('.view-main', {
//		dynamicNavbar : true
	});

	f7.alertMessage = function(title, time) {
		f7.modal({
			text : title,
		});
		var defaultTime = 3000;
		if (time) {
			defaultTime = time;
		}

		setTimeout(function() {
			f7.hidePreloader();
		}, defaultTime);
	}
  
	function updateVersion(response) {
		// 判断是否强制更新
		if (response.appIsForceUpdate) {
			f7.modal({
				title : response.appVersionTitle,
				text : response.appVersionMsg,
				buttons : [{
					text : '确定',
					close: false,
					onClick : function() {
						window.jumpLink(response.appDownloadUrl);
					}
				}]
			});
		} else {
			f7.modal({
				title : response.appVersionTitle,
				text : response.appVersionMsg,
				buttons : [ {
					text : '取消'
				}, {
					text : '确定',
					close: false,
					onClick : function() {
						window.jumpLink(response.appDownloadUrl);
					}
				}

				]
			});
		}
	}
 
	// 获取加密参数
	function getSecurityKey() {
		// console.log('app.js getSecurityKey')
		
		var crypt = new JSEncrypt();
		crypt.setPublicKey(RsaPublicKey);
		
		var reqUrl = host + '/application/security/getSecurityKey';
		var reqParam = crypt.encrypt(JSON.stringify({
			appVersion: version.appVersionCode || '',
			apiVersion: '1.0',
			sessionToken: '',
			accountId: '',
			accountRole: '1',
			optionsMethod: '',
			body: JSON.stringify({
				securityRsaPublicKey: RsaPublicKey,
			}),
			// sparta参数
			blackBox: fp,
			blackBoxType: 'SPARTA'
		}));
		
		if (SKIP.cordova_http) {
			$$.ajax({
			  url: reqUrl,
			  type: 'POST',
			  contentType: 'application/json',
			  timeout: 31000,
			  data: reqParam,
			  success: function(response) {
				  checkVersion();
			  },
			  error: function(err) {
				  f7.hideIndicator();
				  f7.alertMessage('连接有问题，请稍后尝试');
			  }
			});
		} else {
			cordovaHTTP.postJson(reqUrl, reqParam, {}, function(res) {
			  var response = JSON.parse(res.data);
			  
			  checkVersion();
		  }, function(error) {
		    	f7.hideIndicator();
		    	f7.alertMessage('连接有问题，请稍后尝试');
		  });
		}
	}
	
	// 从旧app模块跳入新app，不检查更新
	// 检查版本更新
	function checkVersion() {
	  if (typeof sessionStorage.getItem('go') === 'string' && sessionStorage.getItem('go') === '' || sessionStorage.getItem('go') === null) {
		  // console.log('app.js checkVersion')
		  
		  var reqUrl = host + '/api/checkVersion';
		  var reqParam = {
			  appVersion: version.appVersionCode || '',
			  apiVersion: '1.1',
			  sessionToken: '',
			  accountId: '',
			  accountRole: '1',
			  optionsMethod: '',
			  body: JSON.stringify({
				  appName: 'APP_USER',
				  deviceType: getDeviceType(),
				  appVersionName: '未定义',
				  appVersionCode: version.appVersionCode
			  }),
			  // sparta参数
			  blackBox: fp,
			  blackBoxType: 'SPARTA'
		  };
		  
		  if (SKIP.cordova_http) {
			  $$.ajax({
				  url: reqUrl,
				  type: 'POST',
				  contentType: 'application/json',
				  timeout: 31000,
				  data: JSON.stringify(reqParam),
				  success: function(response) {

					  if (response.code === '2000') {
						var responseData = response.data;
						
						// 检查版本请求成功调用字典请求
						getDict();
						
						// 新版本号大于当前版本
						if (responseData.appVersionCode > version.appVersionCode) {
							
							// 如果是IOS设备，对更新有特殊要求
							if (getDeviceType() === 'IOS') {
								// 是否可以提示
								if (responseData.appIsPromptUser) {
									updateVersion(responseData);
								}
							} else {
								updateVersion(responseData);
							}
						}
					  } else if (response.code === '4000') {
						  f7.alert(response.message);
					  }
				  },
				  error: function(err) {
					  f7.alert('连接有问题，请稍后重试');
				  }
			  });
		  } else {
			  cordovaHTTP.postJson(reqUrl, reqParam, {}, function(res) {
				  var response = JSON.parse(res.data);
				  
				  if (response.code === '2000') {
					var responseData = response.data;
					
					// 检查版本请求成功调用字典请求
					getDict();

					// 新版本号大于当前版本
					if (responseData.appVersionCode > version.appVersionCode) {
						
						// 如果是IOS设备，对更新有特殊要求
						if (getDeviceType() === 'IOS') {
							// 是否可以提示
							if (responseData.appIsPromptUser) {
								updateVersion(responseData);
							}
						} else {
							updateVersion(responseData);
						}
					}
				  } else if (response.code === '4000') {
					  f7.alert(response.message);
				  }
			  }, function(error) {
			    	f7.hideIndicator();
			    	f7.alertMessage('连接有问题，请稍后尝试');
			  });
		  }
	  }
	}
	
	
	function getDict() {
		// console.log('app.js getDict');
		
		var reqUrl = host + '/api/dict';
		var reqParam = {
		    appVersion: version.appVersionCode || '',
		    apiVersion: '1.0',
		    sessionToken: '',
		    accountId: '',
		    accountRole: '1',
		    optionsMethod: '',
		    body: JSON.stringify({
		    	dictSysName: 'APP_USER'
		    }),
		    // sparta参数
		    blackBox: fp,
		    blackBoxType: 'SPARTA'
	    };
		
		function dictSuccessCallback(response) {
			dictData.data = response.data;
			 
			dictData.message = response.data.filter(function(item) {
				if (item.dictKey === 'APP_USER_MSG') { return true; } else { return false; }
			});
			 
			dictData.prompt = response.data.filter(function(item) {
				if (item.dictKey === 'APP_KEY_APPLIANCE_CREDIT_LIMIT_MSG') { return true; } else { return false; }
			});
			 
			dictData.config = response.data.filter(function(item) {
				if (item.dictKey === 'FLS_CONFIG_AES_KEY') { return true; } else { return false; }
			});
			
			dictData.system = response.data.filter(function(item) {
				if (item.dictKey === 'CUSTOMER_SERVICE_PHONE_NUMBER') { return true } else { return false; }
			});
		}
		
		
		if (SKIP.cordova_http) {
			$$.ajax({
				url: host + '/api/dict',
				type: 'POST',
				contentType: 'application/json',
				timeout: 31000,
			    data: JSON.stringify(reqParam),
			    success: function(response) {
			    	dictSuccessCallback(response);
			    },
			    error: function(err) {
			    	f7.hideIndicator();
			    	f7.alertMessage('连接有问题，请稍后尝试');
			    }
		    })
		} else {
			cordovaHTTP.postJson(reqUrl, reqParam, {}, function(res) {
				var response = JSON.parse(res.data);
				
				dictSuccessCallback(response);
			}, function(err) {
		    	f7.hideIndicator();
		    	f7.alertMessage('连接有问题，请稍后尝试');
			});
		}
	}

//	getSecurityKey();
	checkVersion();
	
  return {
	updateVersion: updateVersion,
	getDeviceType: getDeviceType
  };
});
