define([
  'jquery',
  'js/utilities',
  'js/config',
  'containers/order/orderHelper',
  'hbs!containers/orderDetail/orderDetailEmployeeBuy',
  'hbs!components/order/orderInfo/employeeBuyOrderInfo',
  'hbs!components/common/protocolArea/protocolFrame'
], function(
  $$,
  utilities,
  config,
  orderHelper,
  orderDetailEmployeeBuyTemplate,
  employeeBuyOrderInfoTemplate,
  protocolFrame
) {
	var callAppApi = utilities.callAppApi;
	var callWebHtml = utilities.callWebHtml;
	var getEmployeeBuyOrderView = orderHelper.getEmployeeBuyOrderView;
	function render(params) {
		var loginStatus = JSON.parse(localStorage.getItem('loginStatus'));
		
		//渲染navbar
		loadComponent('navbar', 'common', {
			container: '#orderDetailNavbar',
			title: '订单详情',
			backId: 'orderDetailEmployeeBuyBackBtn',
			isBackIcon: true,
			isBack: false,
			callback: function() {
				
				$$('#orderDetailEmployeeBuyBackBtn').off('click').on('click', function() {
					if (params.orderStatus =="20") {
						f7.modal({
							title : '',
							text : '是否退出？',
							buttons : [ {
								text : '取消'
							}, {
								text : '确定',
								onClick : function() {
									mainView.router.load({
							  			url: 'order.html',
							  			force: true
							  		});
								}
							}]
						});
					} else {
						if (params.fromPage=="billing") {
							mainView.router.load({
								url : 'billing.html',
								query : {
									fromPage: 'orderDetail',
									orderId: params.orderId,
									baseBusinessType: params.baseBusinessType,
								}
							});
						} else {
					  		mainView.router.load({
					  			url: 'order.html',
					  			force: true
					  		});

						}
					}
				});
			}
		});
		
		$$('#orderDetailContent').html(orderDetailEmployeeBuyTemplate({
			orderId: params.orderId,
			orderStatus: params.orderStatus,
			goodsSellId: params.goodsSellId,
			goodsSellName: params.goodsSellName,
			orderStatusView: getEmployeeBuyOrderView(params.orderStatus),
			goodsFirstPay: params.goodsSuitePayFirstPrice,											// 更新期初支付字段，差额支付有变更
			goodsPayFirstPrice: params.goodsPayFirstPrice											// 最终支付的金额
		}));
		

		var orderInfoData = {
			goodsInfo: {
				name: params.goodsSellName,
				price: params.orderProductPrice !== '' ? fmoney(params.orderProductPrice, 2, "") + '元' : '',
				orderStatus: params.orderStatus,
				product: {
					key: '分期产品',
					value: params.goodsSellName
				},
				stagingNum: {
					key: '期数',
					value: params.goodsSuiteStageNumber != '' ? params.goodsSuiteStageNumber + '期' : ''
				},
				orderProductPrice: {
					key: '分期金额',
					value: params.orderProductPrice !== '' ? fmoney(params.orderProductPrice, 2, '') + '元' : ''
				},
				firstPay: {
					key: '期初支付',
					value: params.goodsSuitePayFirstPrice != '' ? fmoney(params.goodsSuitePayFirstPrice, 2, '') + '元' : ''
				},
				selfPay: {
					key: '首付款',
					value: params.onlineSelfPayAmount != '' ? fmoney(params.onlineSelfPayAmount, 2, '') + '元' : ''
				},
				goodsPeriodPay: {
					key: '每期还款',
					value: params.goodsSuiteStagePrice != '' ? fmoney(params.goodsSuiteStagePrice, 2, '') + '元' : ''
				},
				deliveryCompany: {
					key: '快递名称',
					value: params.deliveryCompany
				},
				deliveryNo: {
					key: '快递单号',
					value: params.deliveryNo
				},
				orderStoreUserInvoiceNumber: {
					key: '发票号码',
					value: params.orderStoreUserInvoiceNumber
				}
			},
			orderStatus: params.orderStatus
		};
		
		$$('#orderEmployeeBuyDetailInfoArea').html(employeeBuyOrderInfoTemplate(orderInfoData));
		
		$$('#employeeBuyCancleBtn').on('click', function() {
			var orderId = $$(this).parent().data('orderid');
			f7.modal({
				title : '',
				text : '是否确认取消订单',
				buttons : [ {
					text : '取消'
				}, {
					text : '确定',
					onClick : function() {
						callAppApi({
							url: '/app/order/cancel',
							type: 'POST',
							params: {
								userId: loginStatus.userId,
								orderId: orderId,
								baseBusinessType: '005001',
								cancelType: '',
								orderStatus: '50'
							},
							successCallback: function(cancelRes) {
								f7.pullToRefreshTrigger('#orderDetailRefresh');
							},
							errorCallback: function(err) {}
						})
					}
				}]
			});
		})
		
		$$('#employeeBuyConfirmBtn').on('click', function() {
			if ($$(this).parent().data('orderstatus').toString() == '10') {
				loadEmployeeBuyPage('payOrder', {
					query: {
						fromPage: 'order',
						orderId: $$(this).parent().data('orderid'),
						goodsId: $$(this).parent().data('goodsid')
					}
				});
			} else if ($$(this).parent().data('orderstatus').toString() == '20') {
			    loadEmployeeBuyPage('firstPay', {
			    	query: {
						fromPage: 'order',
						orderId: $$(this).parent().data('orderid'),
						goodsName: $$(this).parent().data('goodsname'),
						firstPayPrice: $$(this).parent().data('goodsfirstpay')
					}
			    });
			}
		})
		
		// 员工购查看退换货说明
		$$('#employeeBuyReturnGoodsBtn').on('click', function(e) {
			e.stopPropagation();
			
			callWebHtml({
				url: '/agreement/agrEbuyReturnGoods',
				type: 'POST',
				params: {
					baseBusinessType: '005001'
				},
				successCallback: function(response) {
					$$('#returnGoodsHelpPage').html(protocolFrame({
						protocolId: "returnGoodsHelpContent",
						protocolName: "退换货说明",
						protocolWidth: $('body').width(),
						protocolHeight: $('body').height() - 56
					}));

					$$("#returnGoodsHelpContent").contents().find("html")[0].innerHTML = response;
					
					f7.popup('#returnGoodsHelpPage');
				},
				errorCallback: function(err) {}
			});
		})
	}
	
	function fmoney(s, n , p) {	//格式化金额 s为转化的金额 n为保留几位小数 p为隔开的标点符号 不传默认为","
		if(p === undefined){
			p =",";
		}

	  	if(n){
	  		n = n > 0 && n <= 20 ? n : 2;
			s = parseFloat((s +"").replace(/[^\d\.-]/g,"")).toFixed(n) +"";
	  	}else{
	  		s = parseFloat((s +"").replace(/[^\d\.-]/g,""))+"";
	  	}
		var l = s.split(".")[0].split("").reverse(), r = s.split(".")[1];
		t ="";
		for (i = 0; i < l.length; i++) {
			t += l[i] + ((i + 1) % 3 == 0 && (i + 1) != l.length ? p :"");
		}
		if(n){
			return t.split("").reverse().join("") +"." + r;
		}else {
			return t.split("").reverse().join("")
		}
	}

	return {
		render: render
	}
});