define([
	'jquery',
	'js/utilities'
], function(
	$$,
	utilities
) {
	function getEvidencePicId(evidenceKey) {
		var evidenceIdConfig = {
			'evidenceFrontIdCard': '01',
			'evidenceBackIdCard': '02',
			'evidenceInvoice': '03',
			'evidenceHoldIdCard': '04',
			'evidenceWork': '05',
			'evidenceDwelling': '06',
			'evidenceQualification': '07',
			'evidenceOther': '08',
			'evidenceFace': '09'
		}
		
		if (evidenceIdConfig[evidenceKey]) {
			return evidenceIdConfig[evidenceKey];
		} else {
			console.error('获取上传图片id错误。');
		}
	}
	function getEvidencePicIndex(evidenceIndex) {
		
		return Date.now().toString();
	}
	
	function getEvidencePicName(evidenceKey) {
		var evidenceNameConfig = {
			'evidenceFrontIdCard': '身份证正面',
			'evidenceBackIdCard': '身份证反面',
			'evidenceIdCard': '身份证明材料',
			'evidenceHoldIdCard': '手持身份证照片',
			'evidenceInvoice': '发票图片',
			'evidenceWork': '工作收入证明材料',
			'evidenceDwelling': '居住证明材料',
			'evidenceQualification': '资质证明材料',
			'evidenceOther': '其他材料',
			'evidenceFace': '人脸识别图片'
		};
		
		if (evidenceNameConfig[evidenceKey]) {
			return evidenceNameConfig[evidenceKey];
		} else {
			console.error('获取上传图片名称错误');
		}
	}
	
	function getEvidenceType(evidenceKey) {
		var evidenceTypeConfig = {
			'evidenceFrontIdCard': {},
			'evidenceBackIdCard': {},
			'evidenceIdCard': {
				promptText: '',
			},
			'evidenceWork': {
				promptText: '',
				evidenceInstance: [
					{
						key: 'evidenceWork1',
						header: '工作收入证明材料',
						type: '1',
						prompt: [
							'以下各项任选其一上传即可：',
							'① 本人最近3个月的社保或公积金记录(需显示公司名称)',
							'② 本人工作证或工牌照片，体现信息包括但不限于公司名称、客户姓名、职位、工号、照片等；',
							'③ 本人最近3个月的银行卡工资流水截屏或照片',
							'④ 个体私营业主可上传营业执照照片'
						]
					}
				]
			},
			
			'evidenceDwelling': {
				promptText: '',
				evidenceInstance: [
					{
						key: 'evidenceDwelling1',
						type: '1',
						header: '居住证明材料',
						prompt: [
							'以下各项任选其一上传即可：',
							'① 本人持有的房产证、购房合同或购房发票照片',
							'② 近两个月信用卡、按揭贷款等银行对账单',
							'③ 本人的房租发票/房屋租赁合同'
						]
					}
				]
			},
			
			'evidenceQualification': {
				promptText: '',
				evidenceInstance: [
					{
						key: 'evidenceQualification1',
						type: '1',
						header: '芝麻信用分材料',
						prompt: [
							'上传本人的芝麻信用分数的截屏'
						]
					},
					{
						key: 'evidenceQualification2',
						header: '交易订单截屏',
						type: '2',
						prompt: [
							'以下两种任选其一即可：',
							'1.上传本人在淘宝或京东的最近一笔订单详情截屏',
							'2.上传本人近三个月内任一期的公用事业费缴费单据截屏'
						]
					},
					{
						key: 'evidenceQualification3',
						header: '公用事业费截屏',
						type: '3',
						prompt: [
							'最近三个月任一期公用事业费截屏'
						]
					}
				]
			},
			
			'evidenceOther': {
				promptText: '',
				evidenceInstance: [
					{
						key: 'evidenceOther1',
						header: '其他证明材料',
						type: '1',
						prompt: [
							'请上传本人近三个月通话详单截屏或照片'
						]
					}
				]
			}
		}
		
		if (evidenceTypeConfig[evidenceKey]) {
			return evidenceTypeConfig[evidenceKey];
		} else {
			console.error('获取上传图片配置错误');
		}
	}
	
	function EvidenceArea(tar, dataArr, options) {
		this.tarKey = tar;
		// 证件列表
		this.evidenceList = $$('#' + tar + 'List');
		// 编辑按钮
		this.editBtn = $$('#' + tar + 'EditBtn');
		// 新增按钮
		this.addBtn = $$('#' + tar + 'AddBtn');
		
		// 数据数组
		this.evidenceDataArr = dataArr;
		
		// 选项参数
		this.options = options;
		
		// 初始化
		this.init();
	}
	
	EvidenceArea.prototype = {
		
		addIndex: 0,
		
		init: function() {
			var that = this;
			
			this.addBtn.off('click').on('click', function(e) {
				that.addEvent();
			});
			
			this.editBtn.off('click').on('click', function(e) {
				that.editEvent(e);
			});
		},
		
		clickEvent: function() {
			
			var that = this;
			var evidenceItemList = this.evidenceList.children();
			
			for (var i = 0; i < evidenceItemList.length; i++) {
				if (evidenceItemList[i].id !== this.tarKey + 'AddBtn') {
					$$(evidenceItemList[i]).off('click').on('click', function(e) {
						
						// 删除事件
						if ($$(this).hasClass('evidence-item-delete')) {
							that.removeEvent(e);
						// 预览事件
						} else {
							utilities.clickDelay('previewPhoto', function(){
								that.previewEvent(e);
							}, 500)
						}
					});
				}
			}
		},
		
		addEvent: function() {
			
			this.resetEditEvent();
			
			// 获取点击 添加按钮 的index
			this.addIndex = $$('#' + this.tarKey + 'AddBtn').index();
			
			if (this.addIndex < this.options.limitNum) {
				var uploadPhoto = this.options.uploadPhoto;

				uploadPhoto({
					type: this.tarKey,
					picId: getEvidencePicIndex()
				});
			} else {
				this.options.limitCallback();
			}
		},
		
		addSuccessEvent: function(picId, src) {
			
			this.addIndex = $$('#' + this.tarKey + 'AddBtn').index();
			// 获取点击 添加按钮 的index
			var evidenceItem = document.createElement('li');
			var evidenceItemImg = document.createElement('img');
			$$(evidenceItem).insertBefore(this.addBtn);
			evidenceItem.appendChild(evidenceItemImg);
			$(evidenceItemImg).css('display','none');
			
			evidenceItem.picId = picId;
			evidenceItem.setAttribute('data-picId', picId);
			evidenceItem.classList.add('upload-evidence-item');
			evidenceItem.style.backgroundImage = "url('img/placeOrder/loading1.png')"
			evidenceItem.style.paddingTop = '23%';
			evidenceItem.id = this.tarKey + this.addIndex;
			
			evidenceItem.style.width = '23%';
			$(evidenceItemImg).css({
				'width': '100%',
				'height': $(evidenceItemImg).parent().innerWidth() + 'px',
			}).attr('src',src);
			
			evidenceItemImg.onload = function(){
				evidenceItem.style.backgroundImage = 'none'
				evidenceItem.style.paddingTop = 0;
				evidenceItemImg.style.display = "block";
				
				// 张晖修改于2017-03-10版本，解决上传图片过程中网速过慢，还可以继续上传的bug
				f7.hideIndicator();
			}

			// 绑定点击事件
			this.clickEvent();
		},
		
		removeEvent: function(e) {

			var evidenceType;
			if ($$(e.target)[0].tagName === 'LI') {
				evidenceType = $$(e.target).attr('id').slice(-2, -1);
			} else if ($$(e.target)[0].tagName === 'IMG') {
				evidenceType = $$(e.target).parent().attr('id').slice(-2, -1);			
			}
			
			// 在数据中删除该项
			var curIndex = 0;
			for (var i = 0; i < this.evidenceDataArr.length; i++) {
				
				if (this.evidenceDataArr[i].picType === evidenceType) {
					if (curIndex === $$(e.target).index()) {
						this.evidenceDataArr.splice(i, 1);
					}
					curIndex++;
				}
			}
			
			// 调用删除回调函数，参数为e
			this.options.removeCallback(e);

			// 在表现上删除该项
			if ($$(e.target)[0].tagName === 'LI') {
				$$(e.target).remove();
			} else if ($$(e.target)[0].tagName === 'IMG') {
				$$(e.target).parent().remove();
			}

			// 更新点击 添加按钮 的index
			this.addIndex = $$('#' + this.tarKey + 'AddBtn').index();

			if (this.evidenceList.children().length <= 1) {
				this.resetEditEvent();
			}
			
		},
		
		editEvent: function(e) {
			
			var evidenceItemList = this.evidenceList.children();
			
			if (evidenceItemList.length > 1) {
				if ($$(e.target).text() === '编辑') {
					$$(e.target).text('完成');
					
					for (var i = 0; i < evidenceItemList.length; i++) {
						if (evidenceItemList[i].id !== this.tarKey + 'AddBtn') {
							evidenceItemList[i].classList.add('evidence-item-delete');
						}
					}
				} else if ($$(e.target).text() === '完成') {
					
					this.resetEditEvent();
				}
			} else if (evidenceItemList.length <= 1) {
				this.resetEditEvent();
			}
		},
		
		resetEditEvent: function() {
			
			var evidenceItemList = this.evidenceList.children();
			
			this.editBtn.text('编辑');
			
			for (var j = 0; j < evidenceItemList.length; j++) {
				if (evidenceItemList[j].id !== this.tarKey + 'AddBtn') {
					evidenceItemList[j].classList.remove('evidence-item-delete');
				}
			}
		},
		
		previewEvent: function(e) {
			this.options.previewCallback(e);
		}
	}
	
	return {
		EvidenceArea: EvidenceArea,
		getEvidencePicId: getEvidencePicId,
		getEvidencePicIndex: getEvidencePicIndex,
		getEvidencePicName: getEvidencePicName,
		
		getEvidenceType: getEvidenceType
	}
	
});
