define([
	'jquery',
	'js/utilities',
	'hbs!employeeBuy/employeeBuyComponents/common/searchbar/searchbarArea',
	'hbs!employeeBuy/employeeBuyComponents/common/searchbar/searchbarBrand',
	'hbs!employeeBuy/employeeBuyComponents/common/searchbar/searchbarPrice',
	'hbs!employeeBuy/employeeBuyContainers/goodsList/goodsList',
	'hbs!employeeBuy/employeeBuyComponents/goodsList/goodsListItem'
], function(
	$$,
	utilities,
	searchbarAreaTemplate,
	searchbarBrandTemplate,
	searchbarPriceTemplate,
	goodsListTemplate,
	goodsListItemTemplate
) {
	var $ = Framework7.$;
	var callAppApi = utilities.callAppApi;
	function render(params) {
		var goodsListSearchbar;
		
		// 渲染navbar
		loadEmployeeBuyComponent('navbar', 'common', {
			container: '#goodsListNavbar',
			title: '员工专享',
			backId: 'goodsListBackBtn',
			isBackIcon: true,
			isBack: false,
			callback: function() {
				$('#goodsListBackBtn').on('click', function() {
					loadEmployeeBuyPage('employeeBuyIndex', {});
				});
			}
		});

		// 渲染主页面
		$('#goodsListContent').html(goodsListTemplate({}));
		
		// 商品列表商品展示图片
		$('.goodsList-item').on('click', function() {
			loadEmployeeBuyPage('goodsDetail', {
				query:{
					fromPage: 'employeeBuyGoodsList',
					goodsId: $(this).data("key")
				}
			});
		});
		
		var searchbarStatus = false;
		
		// 渲染搜索栏
		loadEmployeeBuyComponent('searchbar', 'common', {
			searchbarKey: 'GL',
			container: '#goodsListSearchbarArea',
			searchbarId: 'goodsListSearchbar',
			searchbarInputId: 'goodsListSearchbarInputId',
			cancelBtnId: 'goodsListCancelBtn',
			cancelText: '取消',
			placeholder: '请输入关键字搜索商品',
			
			contentContainer: '#goodsListSearchbarContent',
			notFoundArea: 'goodsListNotFoundArea',
			foundArea: 'goodsListFoundArea',

			searchbarStatus: searchbarStatus,												// 使用静态表现替换input搜索
			conditionStatus: true,
			conditionAreaResetCallback: function() {
				$$('#GLSearchbarAreaForm input').prop('checked', false);
				
				$$('#GLChooseAreaView').text('全部');
			},
			conditionBrandResetCallback: function() {
				$$('#GLSearchbarBrandForm input').prop('checked', false);
				
				$$('#GLChooseBrandView').text('品牌');
			},
			conditionConfirmCallback: function(e) {
				$$('#GLSearchbarConditionHeader .tab-link').removeClass('active');
				$$(e.target).closest('.tab').addClass('active');
				$$('#GLSearchbarConditionContent').addClass('hide');
				
				var conditionChannelArr = f7.formToJSON('#GLSearchbarAreaForm').GLConditionChannel;
				if (Array.isArray(conditionChannelArr) && conditionChannelArr.length > 0 && conditionChannelArr[0] == '') {
					conditionChannelArr.shift();
				}
				
				var conditionBrandArr = f7.formToJSON('#GLSearchbarBrandForm').GLConditionBrand;
				if (Array.isArray(conditionBrandArr) && conditionBrandArr.length > 0 && conditionBrandArr[0] == '') {
					conditionBrandArr.shift();
				}
				
				var priceOrderBy = getPriceOrderBy();
				
				searchGoodsList($("#goodsListSearchbarInputId").text(), {
					channelIds: conditionChannelArr,
					goodsBrandsIds: conditionBrandArr,
//					categoryId: params.categoryId,					// 确认时不再保存品类id
					orderBy: priceOrderBy
				});
			},
			afterRender: function() {
				
				$('#goodsListSearchbarInputId').text(params.goodsKeywords);

				// 发送商品列表请求
				searchGoodsList(params.goodsKeywords, {
					channelIds: params.channelIds,
					goodsBrandsIds: params.goodsBrandIds,
					categoryId: params.categoryId,						// 进入渲染时，价格排序时需要传入categoryId
					orderBy: ''
				});
				
				// 如果显示
				if (searchbarStatus === true) {
					// 点击空白区域隐藏
					$('#GLSearchbarConditionContent').on('click', function(e) {
						if (e.path[0].id === 'GLSearchbarConditionContent') {
							$('#GLSearchbarConditionContent').addClass('hide');
						}
					});

					// 当搜索框内文字变化时，显示清除按钮
					$('#goodsListSearchbarInputId').on('keyup', function(e) {
						(function(that) {
							if ($(that).val() == '') {
								$('#goodsListSearchbar').removeClass('searchbar-not-empty');
								$('#goodsListSearchbar').removeClass('searchbar-active');
							} else {
								$('#goodsListSearchbar').addClass('searchbar-not-empty');
								$('#goodsListSearchbar').addClass('searchbar-active');
							}
						})(this);
					});
					
					// 清除按钮绑定事件
					$('.searchbar-clear').on('click', function() {
						setTimeout(function() {
							$('#goodsListSearchbar').removeClass('searchbar-not-empty');
							$('#goodsListSearchbar').removeClass('searchbar-active');
						});
					});
					
					$('#goodsListSearchbarInputId').on('focus', function() {
						$('#goodsListSearchbarContent').removeClass('hide');
					});
					
					$('#goodsListSearchbarInputId').on('change', function() {
						$('#goodsListIndexFoundArea').html('');
					});
					
					goodsListSearchbar = f7.searchbar('#goodsListSearchbar', {
						type: 'customizeSearch',
						customSearch: true,
						onSearch: function() {
							$('#GLSearchbarConditionHeader').removeClass('hide');
							
							var conditionChannelArr = f7.formToJSON('#GLSearchbarAreaForm').GLConditionChannel;
							if (Array.isArray(conditionChannelArr) && conditionChannelArr.length > 0 && conditionChannelArr[0] == '') {
								conditionChannelArr.shift();
							}
							
							var conditionBrandArr = f7.formToJSON('#GLSearchbarBrandForm').GLConditionBrand;
							if (Array.isArray(conditionBrandArr) && conditionBrandArr.length > 0 && conditionBrandArr[0] == '') {
								conditionBrandArr.shift();
							}
							
							var priceOrderBy = getPriceOrderBy();
							
							searchGoodsList($("#goodsListSearchbarInputId").text(), {
								channelIds: conditionChannelArr,
								goodsBrandsIds: conditionBrandArr,
//								categoryId: params.categoryId,					// 搜索时不再保存品类id
								orderBy: priceOrderBy
							})
						}
					});
				} else {
					$('#goodsListSearchbarInputId').on('click', function() {
						loadEmployeeBuyPage('search', {
							query: {
								fromPage: 'employeeBuyGoodsList',
								goodsKeywords: $("#goodsListSearchbarInputId").text()
							}
						});
					})
				}
			}
		});
		
		// 搜索商品列表
		function searchGoodsList(goodsKeywords, condition) {
			var goodsKeywords = goodsKeywords || '';
			var channelIds = condition.channelIds || [];
			var goodsBrandsIds = condition.goodsBrandsIds || [];
			var categoryId = condition.categoryId || '';
			var orderBy = condition.orderBy || '';
			
			
			if (Array.isArray(channelIds) && channelIds.length > 0 && channelIds[0] == '') {
				channelIds.shift();
			}
			if (Array.isArray(goodsBrandsIds) && goodsBrandsIds.length > 0 && goodsBrandsIds[0] == '') {
				goodsBrandsIds.shift();
			}

			callAppApi({
				url: '/app/ebuyCommon/getGoodsList',
				type: 'POST',
				params: {
					goodsKeywords: goodsKeywords,
					channelIds: channelIds,
					goodsBrandIds: goodsBrandsIds,
					categoryId: categoryId,
					orderBy: orderBy
				},
				apiVersion: '1.1',
				successCallback: function(goodsListRes) {
					// 处理键盘没有回落的问题
					$$('#goodsListSearchbarInputId').blur();
					
					var conditionBrandList = [];
					var conditionChannelList = [];
					var conditionPriceList = [];
					var goodsListResultData = goodsListRes.GoodList;
					
					// 显示条件栏
					$('#GLSearchbarConditionHeader').removeClass('hide');
					
					$$('#GLSearchbarConditionHeader .tab-link').off('click.employeeBuyGoodsList').on('click.employeeBuyGoodsList', function(e) {

						if ($$(e.target).attr('id') == 'GLChooseDefaultView' || $$(e.target).children(0).attr('id') == 'GLChooseDefaultView') {
							$$('#GLSearchbarAreaForm input').prop('checked', false);
							$$('#GLChooseAreaView').text('全部');
							$$('#GLSearchbarBrandForm input').prop('checked', false);
							$$('#GLChooseBrandView').text('品牌');
							
							$$('#GLChoosePriceView').text('价格');
							$$('#GLTabChoosePriceBtn').removeClass('top-active').removeClass('bottom-active');
							
							e.stopPropagation();
							
							searchGoodsList($("#goodsListSearchbarInputId").text(), {
								channelIds: [],
								goodsBrandsIds: []
							});
							
							$$('#GLSearchbarConditionContent').addClass('hide');
						} else if ($$(e.target).attr('id') == 'GLChoosePriceView' || $$(e.target).children(0).attr('id') == 'GLChoosePriceView' || $$(e.target).prev().attr('id') == 'GLChoosePriceView') {
							if (!$$(this).hasClass('top-active')) {
								$$(this).removeClass('bottom-active').addClass('top-active');
							} else {
								$$(this).removeClass('top-active').addClass('bottom-active');
							}
							
							var conditionChannelArr = f7.formToJSON('#GLSearchbarAreaForm').GLConditionChannel;
							if (Array.isArray(conditionChannelArr) && conditionChannelArr.length > 0 && conditionChannelArr[0] == '') {
								conditionChannelArr.shift();
							}
							
							var conditionBrandArr = f7.formToJSON('#GLSearchbarBrandForm').GLConditionBrand;
							if (Array.isArray(conditionBrandArr) && conditionBrandArr.length > 0 && conditionBrandArr[0] == '') {
								conditionBrandArr.shift();
							}
							
							var priceOrderBy = getPriceOrderBy();
							
							searchGoodsList($$("#goodsListSearchbarInputId").text(), {
								channelIds: conditionChannelArr,
								goodsBrandsIds: conditionBrandArr,
								orderBy: priceOrderBy
							})
							
							$$('#GLSearchbarConditionContent').addClass('hide');
						} else {
							$$('#GLSearchbarConditionContent').removeClass('hide');
						}

						$$('#GLSearchbarConditionHeader .tab-link').removeClass('active');
						$$(e.target).closest('.tab-link').addClass('active');
					});
					
					Dom7.each(goodsListRes.Brand, function(key, val) {
						conditionBrandList.push({
							name: 'GLConditionBrand',
							value: key,
							view: val,
							checkedStatus: true
						});
					});
					
					conditionBrandList.unshift({
						name: 'GLConditionBrand',
						value: '',
						view: '全部',
						checkedStatus: true
					});
					
					// 渲染品牌条件
					$('#GLTabChooseBrandContent').html(searchbarBrandTemplate({
						searchbarKey: 'GL',
						searchbarBrandData: conditionBrandList
					}));
					
					Dom7.each(goodsListRes.Channel, function(key, val) {
						conditionChannelList.push({
							name: 'GLConditionChannel',
							value: key,
							view: val,
							checkedStatus: true
						});
					});
					
					conditionChannelList.unshift({
						name: 'GLConditionChannel',
						value: '',
						view: '全部',
						checkedStatus: true
					});
					
					// 渲染专区条件
					$('#GLTabChooseAreaContent').html(searchbarAreaTemplate({
						searchbarKey: 'GL',
						searchbarAreaData: conditionChannelList
					}));

					// 渲染搜索结果
//					$('#goodsListList').html(goodsListItemTemplate({
//						goodsListData: goodsListResultData
//					}));
//					$('#goodsListFoundArea').html(goodsListItemTemplate({
//						goodsListData: goodsListResultData
//					}));

					if (Array.isArray(goodsListResultData) && goodsListResultData.length > 0) {
						$('#goodsListSearchbarContent').addClass('hide');
						
						var defaultGoodsImg = './img/employeeBuy/placeholder/goods-placeholder.jpg';
						if (goodsListResultData && Array.isArray(goodsListResultData)) {
							goodsListResultData.forEach(function(item) {
								if (!(typeof item.goodsImage == 'string' && item.goodsImage !== '')) {
									item.goodsImage = defaultGoodsImg;
								}
							});
						}
						
						$('#goodsListList').html(goodsListItemTemplate({
							goodsListData: goodsListResultData
						}));
					} else {
						$('#goodsListList').html(goodsListItemTemplate({
							goodsListData: []
						}));
						
						$$('.notFoundBtn').on('click', function() {
							loadEmployeeBuyPage('employeeBuyIndex', {
								query: {
									fromPage: 'goodsList'
								}
							});
						});
					}
					
					$('.goodsList-item').on('click', function(e) {
						loadEmployeeBuyPage('goodsDetail', {
							query: {
								fromPage: 'employeeBuyGoodsList',
								goodsId: $(e.currentTarget).data('key')
							}
						});
					});
					
					// 专区选项的点击事件
					$$("#GLTabChooseArea .tab-choose-area-item").off('click.employeeBuyGoodsList').on('click.employeeBuyGoodsList',function(e){	
						
						setTimeout(function() {
							if ($$(e.currentTarget).find("input").val() == '') {
								if ($$(e.currentTarget).find('input').prop('checked') == true) {
									$$('#GLTabChooseArea input').prop('checked', true);
								} else {
									$$('#GLTabChooseArea input').prop('checked', false);
								}
							} else {
								if ($$(e.currentTarget).find('input').prop('checked') == true) {
										
								} else {
									$$('#GLTabChooseArea input')[0].checked = false;
								}
							}
							
							// 获取当前专区已经被选择的id列表
							var tempAreaCondition = f7.formToJSON('#GLSearchbarAreaForm').GLConditionChannel;
							
							var tempAreaId = '';
							var tempAreaView = '全部'
							if (Array.isArray(tempAreaCondition) && tempAreaCondition.length > 0) {
								tempAreaId = tempAreaCondition[0];
							}
							
							conditionChannelList.forEach(function(item, index) {
								if (item.value == tempAreaId) {
									tempAreaView = item.view;
								}
							});
							
							$$('#GLChooseAreaView').text(tempAreaView);
						});
					});

					$$("#GLTabChooseBrand .tab-choose-brand-item").off('click.employeeBuyGoodsList').on('click.employeeBuyGoodsList',function(e){
						
						setTimeout(function() {
							if ($$(e.currentTarget).find("input").val() == '') {
								if ($$(e.currentTarget).find('input').prop('checked') == true) {
									$$('#GLTabChooseBrand input').prop('checked', true);
								} else {
									$$('#GLTabChooseBrand input').prop('checked', false);
								}
							} else {
								if ($$(e.currentTarget).find('input').prop('checked') == true) {
										
								} else {
									$$('#GLTabChooseBrand input')[0].checked = false;
								}
							}
							
							
							// 获取当前专区已经被选择的id列表
							var tempBrandCondition = f7.formToJSON('#GLSearchbarBrandForm').GLConditionBrand;
							
							var tempBrandId = '';
							var tempBrandView = '品牌'
							if (Array.isArray(tempBrandCondition) && tempBrandCondition.length > 0) {
								tempBrandId = tempBrandCondition[0];
							}
							
							conditionBrandList.forEach(function(item, index) {
								if (item.value == tempBrandId && tempBrandId !== '') {
									tempBrandView = item.view;
								}
							});
							
							$$('#GLChooseBrandView').text(tempBrandView);	
						});
					})
				},
				errorCallback: function(err) {}
			});
		}
		
		// 判断价格排序取值
		function getPriceOrderBy() {
			if ($('#GLTabChoosePriceBtn').hasClass('top-active')) {
				return 'ACT_PRICE';
			} else if ($('#GLTabChoosePriceBtn').hasClass('bottom-active')) {
				return 'ACT_PRICE desc';
			} else {
				return '';
			}
		}

		
//		// 上拉加载事件
//		$('#goodsListContent').on('infinite', function(e) {
//			setTimeout(function() {
//				
//				// 上拉加载
////				var addListData = {
////					goodsListData: [
////						{
////							goodsPic: 'img/iphone.png',
////							goodsName: '苹果iPhone7 金色 128G这是商品名称苹果iPhone7 金色 128G这是商品名称',
////							goodsPricePrompt: '月还款',
////							goodsPrice: '500.00'
////						},
////						{
////							goodsPic: 'img/iphone.png',
////							goodsName: '苹果iPhone7 金色 128G这是商品名称苹果iPhone7 金色 128G这是商品名称iPhone7 金色 128G这是商品名称',
////							goodsPricePrompt: '月还款',
////							goodsPrice: '500.00'
////						}
////					]
////				};
////				
////				var addListHtml = goodsListItemTemplate(addListData);
//				
////				$('#goodsListList').append(addListHtml);
//				
////				$('.goodsList-item').on('click', function() {
////					loadEmployeeBuyPage('goodsDetail', {});
////				});
//			}, 1000);
//		})
	}
	
	return {
		render: render
	}
})
