define(["handlebars"], function (Handlebars) {
  Handlebars = Handlebars || this.Handlebars;

  var templateExtension = ".hbs";

  // 注册compare Helper
  Handlebars.registerHelper('compare', function(left, operator, right, options) {
	  if (arguments.length < 3) {
		  throw new Error('Handlebars Helper "compare" needs 2 parameters');
	  }
	  
	  var operators = {
	    '==': function(l, r) { return l == r; },
	    '===': function(l, r) { return l === r; },
	    '!=': function(l, r) { return l != r; },
	    '!==': function(l, r) { return l !== r; },
	    '<': function(l, r) { return l < r; },
	    '>': function(l, r) { return l > r; },
	    '<=': function(l, r) { return l <= r; },
	    '>=': function(l, r) { return l >= r; },
	    'typeof': function(l, r) { return typeof l === r; }
	  };
	  
	  if (!operators[operator]) {
		  throw new Error('Handlebars Helper "compare" doesn\'t know the operator ' + operator);
	  }
	  
	  var result = operators[operator](left, right);

	  if (result) {
		  return options.fn(this);
	  } else {
		  return options.inverse(this);
	  }
  });
  
  Handlebars.registerHelper('slice', function(str, start, end) {

	  if (end) {
		  return str.slice(start, end);
	  } else {
		  return str.slice(start);
	  }
	  
  });
  
  Handlebars.registerHelper('split', function(str, sep, howmany) {
	  
	  if (sep) {
		  return str.split(sep)[howmany];
	  } else {
		  return str.split(' ')[howmany];
	  }
	  
  });
  
  // registerHelper js_compare
  Handlebars.registerHelper('js_compare', function(expression, options) {
	  var func;

	  if (expression.indexOf('return') >= 0) {
		  func = '(function() {'+expression+'})';
	  } else {
		  func = '(function() {return ('+expression+')})';
	  }
	  
	  var condition = eval.call(this, func).call(this);
	  
	  if (condition) {
		  return options.fn(this, options.data);
	  } else {
		  return options.inverse(this, options.data);
	  }
  });

  Handlebars.registerHelper('formatPrice', function(price) {
	  var curPrice = price.split('.')[0];
	  var restPrice = price.split('.')[1] || '';

	  var n = Math.ceil(parseInt(curPrice.length) / 3);
	  
	  var priceArr = [];
	  
	  for (var i = 0; i < n; i++) {
		  (function(i) {
			  if (i === 0) {
				  priceArr.unshift(curPrice.slice(-3 * (i + 1)).toString());
			  } else {
				  priceArr.unshift(curPrice.slice(-3 * (i + 1), -3 * i).toString());
			  }
		  })(i)
	  }
	  
	  if (restPrice === '') {
		  return priceArr.join(',');
	  } else {
		  return priceArr.join(',') + '.' + restPrice;
	  }
  })
  
  return {

    pluginBuilder: "./hbs-builder",

    // http://requirejs.org/docs/plugins.html#apiload
    load: function (name, parentRequire, onload, config) {

      // Get the template extension.
      var ext = (config.hbs && config.hbs.templateExtension ? config.hbs.templateExtension : templateExtension);

      // In browsers use the text-plugin to the load template. This way we
      // don't have to deal with ajax stuff
      parentRequire(["text!" + name + ext], function (raw) {
        // Just return the compiled template
        onload(Handlebars.compile(raw));
      });

    }

  };
});
