define([
	'jquery',
	'js/config',
	'js/utilities'
], function(
	$$,
	config,
	utilities
) {
	
	var getFormatDate = utilities.getFormatDate;
	var callAppApi = utilities.callAppApi;

	var SKIP = config.SKIP;
	/**
	 * @title 埋点枚举类
	 */
	function getPadEnum(key) {
		switch(key) {
			case 'userIdentityCardNumber':
				return {
					key: 'APP_USER_INPUT_IDCARD_TIME',
					val: '在APP客户端填写申请人身份证号码时增加完成该字段填写的使用时间'
				};
				break;
			case 'userHighestEducation':
				return {
					key: 'APP_USER_INPUT_EDUCATION_TIME',
					val: '在APP客户端填写申请人学历时增加完成该字段填写的使用时间'
				};
				break;
			case 'userMaritalStatus':
				return {
					key: 'APP_USER_INPUT_MARITALSTATUS_TIME',
					val: '在APP客户端填写申请人婚姻状况时增加完成该字段填写的使用时间'
				};
				break;
			case 'userDwellingAddress':
				return {
					key: 'APP_USER_INPUT_DWELLINGADDRESS_TIME',
					val: '在APP客户端填写申请人居住地址时增加完成该字段填写的使用时间'
				}
				break;
			case 'authStep1Btn':
				return {
					key:'APP_USER_AUTHSTEP_NEXTSTEP_TIME_POINT',
					val:'在APP客户端填写完第一页资料后点击“下一步”时增加操作时间的埋点'
				}
				break;				
			case 'userCompanyName':
				return {
					key:'APP_USER_INPUT_COMPANYNAME_TIME',
					val:'在APP客户端填写申请人单位名称时增加完成该字段填写的使用时间'
				}
			case 'userWorkFullAddress':
				return{
					key:'APP_USER_INPUT_COMPANYADDRESS_TIME',
					val:'在APP客户端填写申请人单位地址时增加完成该字段填写的使用时间'
				}
				break;		
			case 'authStep2Btn':
				return {
					key:'APP_USER_AUTHSTEP_FINISH_TIME_POINT',
					val:'在App客户端填写完第二页资料后点击“完成”时增加操作时间的埋点'
				}
				break;		
			case 'placeOrderGoodsBtn':
				return {
					key:'APP_USER_CHOOSEGOODS_NEXTSTEP_TIME_POINT',
					val:'在APP客户端选择商品后点击“下一步”时增加操作时间的埋点'
				}
				break;		
			case 'faceCheckBtn':
				return {
					key:'APP_USER_CHECKFACE_UPLOAD_TIME_POINT',
					val:'在APP客户端选择“人脸识别”时，在最终结果时增加操作时间的埋点'
				}
				break;						
			case 'checkUserIdCardUploadBtn':
				return {
					key:'APP_USER_CHECKFACE_HOLDINCARD_TIME_POINT',
					val:'在APP客户端选择手持证件照“点击上传”时增加操作时间的埋点'
				}
				break;		
			case 'idCardFront':
				return {
					key:'APP_USER_CHECKINFO_UPLOADIDCARD_TIME_POINT',
					val:'在APP客户端上传身份证明时增加操作时间的埋点'
				}
				break;	
			case 'idCardBack':
				return {
					key:'APP_USER_CHECKINFO_UPLOADIDCARD_TIME_POINT',
					val:'在APP客户端上传身份证明时增加操作时间的埋点'
				}
				break;		
			case 'uploadEvidenceConfirmBtn':
				return {
					key:'APP_USER_CHECKINFO_SUBMITAUDIT_TIME_POINT',
					val:'在APP客户端完成各类资料上传后点击“提交审核”时增加操作时间的埋点'
				}
				break;					
			case 'applianceFaceBtn':
				return {
					key:'APP_USER_ORDERDETAIL_CONTINUEORDER_TIME_POINT',
					val:'在APP客户端订单详情页面点击“继续下单”时增加操作时间的埋点'
				}
				break;		
			case 'applianceUploadIdCard':
				return {
					key:'APP_USER_ORDERDETAIL_CONTINUEORDER_TIME_POINT',
					val:'在APP客户端订单详情页面点击“继续下单”时增加操作时间的埋点'
				}
				break;	
			case 'orderConfirmBtn':
				return {
					key:'APP_USER_ORDERDETAIL_CONTINUEORDER_TIME_POINT',
					val:'在APP客户端订单详情页面点击“继续下单”时增加操作时间的埋点'
				}
				break;		
			case 'idCardFrontItem':
				return {
					key:'APP_USER_ORDERDETAIL_REUPLOAD_TIME_POINT',
					val:'在APP客户端订单登记详情点击“重新上传”时增加操作时间的埋点'
				}
				break;	
			case 'idCardBackItem':
				return {
					key:'APP_USER_ORDERDETAIL_REUPLOAD_TIME_POINT',
					val:'在APP客户端订单登记详情点击“重新上传”时增加操作时间的埋点'
				}
				break;		
			case 'userIdCardItem':
				return {
					key:'APP_USER_ORDERDETAIL_REUPLOAD_TIME_POINT',
					val:'在APP客户端订单登记详情点击“重新上传”时增加操作时间的埋点'
				}
				break;		
			case 'orderConfirmBindBankcard':
				return {
					key:'APP_USER_CONFIRMVIEW_BINDDEBITCARD_TIME',
					val:'在APP客户端“确认下单”页面绑定借记卡时增加完成该字段填写的使用时间的埋点'
				}
				break;
			case 'faceCheckBtn':
				return {
					key:'APP_USER_CHECKFACE_UPLOAD_TIME_POINT',
					val:'在APP客户端选择“人脸识别”时，在最终结果时增加操作时间的埋点'
				}
				break;	
			case 'placeOrderConfirmBtn':
				return {
					key:'APP_USER_CONFIRMVIEW_CONFIRMORDER_TIME_POINT',
					val:'在APP客户端订单确认下单页面点击“确认下单”时增加操作时间的埋点'
				}
				break;					
			default: 
				alert('未设置此枚举类型');
				return false;
		}
	}
	
	/**
	 * @title 埋点输入绑定方法
	 * @desc 前端埋点通用输入绑定方法
	 * @param tar: css选择器
	 * @param type: 表单类型 text | select
	 */
	var selectClickIndex = 0;
	// 埋点方法
//	function bindPadInputEvent(tar, type, baseBusinessType, callback) {
	function bindPadInputEvent(params, callback) {
		var tar = params.tar;
		var type = params.type;
		var baseBusinessType = params.baseBusinessType;
		
		if (typeof type === 'undefined') {
			var type = 'text';
		}
		
		var tarName = tar.slice(1);
		
		var recordData = new GetPadRecord({
			tar: tarName,
			baseBusinessType: baseBusinessType
		});
		
		if (type === 'text') {
			$$(tar).off('focus.pad').on('focus.pad', function(e) {
				recordData.startEvent();
			});
			
			$$(tar).off('blur.pad').on('blur.pad', function(e) {
				recordData.endEvent(e.target.value);
				
				callback(recordData.getRecord());
			});
		}
		
		if (type === 'select') {
			
			// 在手机中click事件不触发，修改为touchstart事件
			$$(tar).off('touchstart.pad').on('touchstart.pad', function(e) {
				recordData.startEvent();
			});
			
			$$(tar).off('change.pad').on('change.pad', function(e) {
				recordData.endEvent(e.target.value);
				
				callback(recordData.getRecord());
			})
		}
	}
	/**
	 * @title pad埋点点击绑定方法
	 * @desc 前端埋点通用点击绑定方法
	 * @param tar: css选择器
	 */
//	function bindPadClickEvent(tar, type, baseBusinessType, callback) {
	function bindPadClickEvent(params, callback) {
		
		var tar = params.tar;
		var type = params.type;
		var baseBusinessType = params.baseBusinessType;
		
		var tarName = tar.slice(1);
		
		var recordData = new GetPadRecord({
			tar: tarName,
			baseBusinessType: baseBusinessType
		});
		$$(tar).off('click.pad').on('click.pad', function(e) {
			
			recordData.clickEvent();
			
			callback(recordData.getRecord());
		});
	}
	
	function jumpPagePadEventStart(params, callback) {
		
		var tarKey = params.tarKey;
		var baseBusinessType = params.baseBusinessType;
		
		var recordData = new GetPadRecord({
			tar: tarKey,
			baseBusinessType: baseBusinessType
		});
		
		recordData.startEvent();

		callback(recordData.getRecord());
	}
	
	function jumpPagePadEventEnd(params, callback) {
		
		var record = params.record;
		
		record.operateEndTime = getFormatDate(Date.now());
		
		callback(record);
	}
	
	
	/**
	 * @title 拼装记录的结构
	 * @desc 按照定义的接口格式，拼装出传给后端的记录字段
	 */
	function GetPadRecord(params) {
		var tar = params.tar;
		var baseBusinessType = params.baseBusinessType;
		
		var deviceId = '';
		if (!SKIP.cordova_uuid) {
			deviceId = device.uuid;
		}
		
		this.record = {
			uuid: '',											//唯一标示符
			baseBusinessType: baseBusinessType,					//业务类型
			userName: '',										//姓名
			userPhoneNumber: '',								//手机号
			userIdentityCardNumber: '',							//身份证号
			operateStartTime: '',								//操作开始时间
			operateEndTime: '',									//操作结束时间
			operateContext: '',									//操作内容简称
			operateTimePoint: '',								//操作时间埋点
			deviceId: deviceId,									//设备id 
			operateContextType: '',								//操作内容类型	默认为空
			operateContextKey: getPadEnum(tar).key,				//操作内容表示key
			whetherSend: '0',									//是否默认		默认为0
			sysName: 'APP_USER',								//系统
		};
	}
	
	GetPadRecord.prototype = {
		startEvent: function() {
			this.record.operateStartTime = getFormatDate(Date.now());
		},
		endEvent: function(val) {
			this.record.operateEndTime = getFormatDate(Date.now());
			this.record.operateContext = val;
		},
		clickEvent: function() {
			this.record.operateTimePoint = getFormatDate(Date.now());
		},
		getRecord: function() {
			return this.record;
		}
	}
	
	function sendRecord(params, success, error) {
		
		if ($$.isArray(params.mList) && params.mList.length > 0) {
			params.mList = params.mList.map(function(item) {
				return {
					deviceId: item.deviceId,
					baseBusinessType: item.baseBusinessType,
					operateContext: item.operateContext,
					operateContextKey: item.operateContextKey,
					operateContextType: item.operateContextType,
					operateEndTime: item.operateEndTime,
					operateStartTime: item.operateStartTime,
					operateTimePoint: item.operateTimePoint,
					userIdentityCardNumber: item.userIdentityCardNumber.toUpperCase(),
					userName: item.userName,
					userPhoneNumber: item.userPhoneNumber,
					whetherSend: item.whetherSend,
					systemName: item.sysName
				}
			});
		}
		
		callAppApi({
			url: '/api/reqSaveWindControlPoint',
			type: 'POST',
			params: params,
			showIndicatorStatus: false,					// 默认不显示旋转框
			hideIndicatorStatus: false,					// 默认不隐藏旋转框
			successCallback: function(recordRes) {
				success(recordRes);
			},
//			errorCallback: function(err) {
//				error(err);
//			}
		});
	}
	
	return {
		bindPadInputEvent: bindPadInputEvent,
		bindPadClickEvent: bindPadClickEvent,
		sendRecord: sendRecord,
		
		jumpPagePadEventStart: jumpPagePadEventStart,
		jumpPagePadEventEnd: jumpPagePadEventEnd
	}
})