define(function() {
	
  /**
   * @desc Object.assign polyfill
   * @src https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object/assign
   */
  if (typeof Object.assign !== 'function') {
	Object.assign = function (target, varArgs) {
	  'use strict';
	  if (target === null) {
		throw new TypeError('Cannot convert undefined or null to object');
	  }
	  
	  var to = Object(target);

	  for (var index = 1; index < arguments.length; index++) {
		var nextSource = arguments[index];
		if (nextSource != null) {
		  for (var nextKey in nextSource) {
			// Avoid bugs when hasOwnProperty is shadowed
			if (Object.prototype.hasOwnProperty.call(nextSource, nextKey)) {
			  to[nextKey] = nextSource[nextKey];
			}
		  }
		}
	  }
	  
	  return to;
	};
  }
});

