define([
  'js/config',
  'jquery',
  'js/lib/pawebjs',
  'js/datas'
], function(
  config,
  $$,
  PaWebJs,
  Datas
) {
  var baseHost = config.baseHost;
  var host = config.host;
  var SKIP = config.SKIP;
  var newAppVersion = JSON.parse(localStorage.getItem('version'));
  var dictData = Datas.dictData;
  
  /**
   * @func 兼容旧家装的ajax接口调用方式
   * @param init 可选参数
   * @param callback	回调函数
   * @returns
   */
  function callAppApiNew (init) {

	// 是否在请求开始时展示indicator    
	var showIndicatorStatus = typeof init.showIndicatorStatus === 'undefined' ? true : init.showIndicatorStatus;
    // 是否在请求结束时隐藏indicator
    var hideIndicatorStatus = typeof init.hideIndicatorStatus === 'undefined' ? true : init.hideIndicatorStatus;
	  
    if (showIndicatorStatus) {
    	f7.showIndicator();
    }
	
	var loginStatusStr = localStorage.getItem('loginStatus') || '';
	var loginStatus = loginStatusStr !== '' ? JSON.parse(loginStatusStr) : {};
	
	var appVersionCode = newAppVersion.appVersionCode;
	var apiVersion = newAppVersion.apiVersion;
	
    // sparta webJS
    var fp = new PaWebJs().get();
    
    if (SKIP.console_log) {
    	console.warn('********************* callAppApi 请求值 ********************* : ' + host + init.url);
    	console.log({
    	    appVersion: init.appVersionCode || appVersionCode || '',
    	    apiVersion: init.apiVersion || apiVersion || '',
    	    sessionToken: init.sessionToken || loginStatus.userSession ||'',
    	    accountId: init.accountId || loginStatus.userId || '',
    	    accountRole: init.accountLoginType || loginStatus.accountLoginType || '1',
    	    optionsMethod: init.optionsMethod || '',
    	    body: JSON.stringify(init.params || {}),
            blackBox: fp,
            blackBoxType: 'SPARTA'
    	  });
    	console.warn('************')
    	console.log(init.params || {});
    }

	// @warn: 这的ajax底层方法为 jQuery的 ajax， 其余$为Framework7.$;
	try {
		if (SKIP.cordova_http) {
			$$.ajax({
		      url: encodeURI(/^http[s]?:\/\//.test(init.url) ? init.url : host + init.url),
		      type: init.type || 'POST',
		      contentType: 'application/json',
		      timeout: 31000,
		      headers: {
		    	userId: loginStatus.userId ||'',
		    	sessionToken: init.sessionToken || loginStatus.userSession ||'',
		      },
		      data: JSON.stringify({
		        appVersion: init.appVersionCode || appVersionCode || '',
			    apiVersion: init.apiVersion || apiVersion || '',
		        sessionToken: init.sessionToken || loginStatus.userSession ||'',
		        accountId: init.accountId || loginStatus.userId || '',
		        accountRole: init.accountLoginType || loginStatus.accountLoginType || '1',
		        optionsMethod: init.optionsMethod || '',
		        body: JSON.stringify(init.params || {}),
		        // sparta参数
		        blackBox: fp,
		        blackBoxType: 'SPARTA'
		      }),
		      success: function (response) {

		    	if (SKIP.console_log) {
			    	console.warn('********************* callAppApi 返回值  ********************* : ' + host + init.url);
			    	console.log(response);
		    	}
		    	
		    	if (hideIndicatorStatus) {
		    		f7.hideIndicator();
		    	}
		    	
		    	// 旧返回值code处理方案
		    	if (response.code.length === 4) {
			        if (response.code === '2000') {
			          var responseData = response.data;
			          
			          if (responseData === null) {
			        	  responseData = {};
			          }
			          
			          if (init.successCallback) {
			            init.successCallback(responseData);
			          }
			        } else if (response.code === '4000') {
			        	
			          if (init.errorCallback) {
			        	f7.alertMessage(response.message);
			            init.errorCallback(response.message);
			          }
			        } else if (response.code === '4001') {
			        	
			        	f7.hidePreloader();
			        	
			        	f7.alertMessage(response.message);
			
			        	logout();
			        	
			        	if (init.logoutCallback) {
			        		init.logoutCallback(response.message);
			        	}
			        } else if (response.code === '4002') {
			        	f7.alertMessage(response.message);
			        	
			        	var timeLink = setTimeout(function() {
//			        		mainView.loadPage('index.html');
			    			mainView.router.load({
			    				url: 'index.html',
			    				animatePages: false
			    			});
			        		
			        		clearTimeout(timeLink);
			        	}, 3000);
			        }
		    	} else if (response.code.length === 8) {
		    		// 员工购 与 其他业务类型 下单区别判断
		    		if (init.params.baseBusinessType && init.params.baseBusinessType == '005001') {	// 如果有业务类型并且为员工购业务类型
		    			if (response.code === '14508000') {									// 如果存在一个员工购的订单
		    				dealWithErrorCode();											// 弹出错误提示框
		    			} else {															// 如果存在其他业务类型订单
		    				dealWithSuccessCode();											// 走可以下单逻辑
		    			}
		    		} else {																// 业务类型不为员工购
			    		// 新返回值code处理方案
			    		if (response.code.slice(-1) === '1') {								// 如果返回code为1结尾，说明可以下单，继续下单
			    			dealWithSuccessCode();											// 继续下单逻辑
			    		} else if (response.code.slice(-1) === '0') {						// 如果返回code为0结尾，说明存在一个订单
			    			// 如果存在一个员工购订单 || 如果存在一个成人教育订单
			    			// 如果存在一个家装线上化订单，通过8位code走成功回调， 特殊处理
			    			if (response.code === '14508000' || response.code === '14507600' || response.code === '14507500' || response.code === '14506100') {								
			    				dealWithSuccessCode();										// 继续下单逻辑
			    			} else {														// 如果存在的不是员工购订单
			    				dealWithErrorCode();										// 如果存在的不是员工购订单，则判断码表弹出提示框
			    			}
			    		}
		    		}

		    		function dealWithSuccessCode() {
		    			if (response.code === '14201001') {
		    				var timeoutOrder = setTimeout(function() {
			    				mainView.router.load({
			    					url: 'order.html'
			    				});
			    				clearTimeout(timeoutOrder);
		    				}, 1000);
		    			} else if (response.code === '14301001') {
		    				var timeoutOrderDetail = setTimeout(function() {
		            	        mainView.router.load({
									url: 'orderDetail.html',
									query: {
									    orderId: response.data.baseOrderId,
									    baseBusinessType: response.data.baseBusinessType
									}
		          		        });
		            	        clearTimeout(timeoutOrderDetail);
		    				}, 1000);
		    			} else {
		    				if (init.successCallback) {
			    				init.successCallback(response)
			    			}
		    			}
		    		}
		    		
		    		function dealWithErrorCode() {
		    			if (init.errorCallback) {
		    				
		    				var alertMessageText = '';
							// 这里接口返回新的码表配置信息
							dictData.message.forEach(function(item) {
								if (item.dictSerialNo === response.code) {
									alertMessageText = item.dictValue;
								}
							});
							
							f7.alertMessage(alertMessageText);
		    				
		    				init.errorCallback(response);
		    			}
		    		}
		    	}
		      },
		      error: function (err) {
		    	  if (init.errorCallback) {
		    		  init.errorCallback(err);
			    	  callAppApi({
			    		  url: '/application/logs/appPlugins',
			    		  type: 'POST',
			    		  params: {
			    			  baseAppName: 'APP_USER',
			    			  baseUserId: loginStatus.userId || '',
			    			  baseOrderId: init.orderId || '',
			    			  pluginTag: 'callAppApi_jqueryAjax_errorCallback',
			    			  requestUrl: /^http[s]?:\/\//.test(init.url) ? init.url : host + init.url,
			    			  requestData: JSON.stringify(init.params || {}),
			    			  responseData: JSON.stringify(err)
			    		  }
			    	  });
		    	  }
		    	  
		    	  f7.hideIndicator();
		    	  f7.alertMessage('连接有问题，请稍后尝试');
		      },
		      complete: function (response) {
		    	  if (hideIndicatorStatus) {
		    		  f7.hideIndicator();
		    	  }
		    	  if (init.completeCallback) {
		    		  init.completeCallback(response.responseJSON);
		    	  }
		      }
		    });
		} else {
			var reqUrl = /^http[s]?:\/\//.test(init.url) ? init.url : host + init.url;
			var reqParam = {
		        appVersion: init.appVersionCode || appVersionCode || '',
			    apiVersion: init.apiVersion || apiVersion || '',
		        sessionToken: init.sessionToken || loginStatus.userSession ||'',
		        accountId: init.accountId || loginStatus.userId || '',
		        accountRole: init.accountLoginType || loginStatus.accountLoginType || '1',
		        optionsMethod: init.optionsMethod || '',
		        body: JSON.stringify(init.params || {}),
		        // sparta参数
		        blackBox: fp,
		        blackBoxType: 'SPARTA'
		    }
			
			cordovaHTTP.setHeader("userId", loginStatus.userId ||'');
			cordovaHTTP.setHeader("sessionToken", init.sessionToken || loginStatus.userSession ||'');
			
			cordovaHTTP.postJson(encodeURI(reqUrl), reqParam, {}, function(res) {
				
				var response = JSON.parse(res.data);
				
		    	if (hideIndicatorStatus) {
		    		f7.hideIndicator();
		    	}
		    	
		    	// 旧返回值code处理方案
		    	if (response.code.length === 4) {
			        if (response.code === '2000') {
			          var responseData = response.data;
			          
			          if (responseData === null) {
			        	  responseData = {};
			          }
			          
			          if (init.successCallback) {
			            init.successCallback(responseData);
			          }
			        } else if (response.code === '4000') {
			        	
			          if (init.errorCallback) {
			        	f7.alertMessage(response.message);
			            init.errorCallback(response.message);
			          }
			        } else if (response.code === '4001') {
			        	
			        	f7.hidePreloader();
			        	
			        	f7.alertMessage(response.message);
			
			        	logout();
			        	
			        	if (init.logoutCallback) {
			        		init.logoutCallback(response.message);
			        	}
			        } else if (response.code === '4002') {
			        	f7.alertMessage(response.message);
			        	
			        	var timeLink = setTimeout(function() {
//			        		mainView.loadPage('index.html');
			    			mainView.router.load({
			    				url: 'index.html',
			    				animatePages: false
			    			});
			        		
			        		clearTimeout(timeLink);
			        	}, 3000);
			        }
		    	} else if (response.code.length === 8) {
		    		// 员工购 与 其他业务类型 下单区别判断
		    		if (init.params.baseBusinessType && init.params.baseBusinessType == '005001') {	// 如果有业务类型并且为员工购业务类型
		    			if (response.code === '14508000') {									// 如果存在一个员工购的订单
		    				dealWithErrorCode();											// 弹出错误提示框
		    			} else {															// 如果存在其他业务类型订单
		    				dealWithSuccessCode();											// 走可以下单逻辑
		    			}
		    		} else {																// 业务类型不为员工购
			    		// 新返回值code处理方案
			    		if (response.code.slice(-1) === '1') {								// 如果返回code为1结尾，说明可以下单，继续下单
			    			dealWithSuccessCode();											// 继续下单逻辑
			    		} else if (response.code.slice(-1) === '0') {						// 如果返回code为0结尾，说明存在一个订单
			    			// 如果存在一个员工购订单 || 如果存在一个成人教育订单
			    			// 如果存在一个家装线上化订单，通过8位code走成功回调， 特殊处理
			    			if (response.code === '14508000' || response.code === '14507600' || response.code === '14507500' || response.code === '14506100') {								
			    				dealWithSuccessCode();										// 继续下单逻辑
			    			} else {														// 如果存在的不是员工购订单
			    				dealWithErrorCode();										// 如果存在的不是员工购订单，则判断码表弹出提示框
			    			}
			    		}
		    		}

		    		function dealWithSuccessCode() {
		    			if (response.code === '14201001') {
		    				var timeoutOrder = setTimeout(function() {
			    				mainView.router.load({
			    					url: 'order.html'
			    				});
			    				clearTimeout(timeoutOrder);
		    				}, 1000);
		    			} else if (response.code === '14301001') {
		    				var timeoutOrderDetail = setTimeout(function() {
		            	        mainView.router.load({
									url: 'orderDetail.html',
									query: {
									    orderId: response.data.baseOrderId,
									    baseBusinessType: response.data.baseBusinessType
									}
		          		        });
		            	        clearTimeout(timeoutOrderDetail);
		    				}, 1000);
		    			} else {
		    				if (init.successCallback) {
			    				init.successCallback(response)
			    			}
		    			}
		    		}
		    		
		    		function dealWithErrorCode() {
		    			if (init.errorCallback) {
		    				
		    				var alertMessageText = '';
							// 这里接口返回新的码表配置信息
							dictData.message.forEach(function(item) {
								if (item.dictSerialNo === response.code) {
									alertMessageText = item.dictValue;
								}
							});
							
							f7.alertMessage(alertMessageText);
		    				
		    				init.errorCallback(response);
		    			}
		    		}
		    	}
			}, function(err) {
			 
		      // 如果进入错误回调函数，则调用errorCallback
			  if (init.errorCallback) {
				  init.errorCallback(err);
				  
		    	  callAppApi({
		    		  url: '/application/logs/appPlugins',
		    		  type: 'POST',
		    		  params: {
		    			  baseAppName: 'APP_USER',
		    			  baseUserId: loginStatus.userId || '',
		    			  baseOrderId: init.orderId || '',
		    			  pluginTag: 'callAppApi_cordovaHTTP_errorCallback',
		    			  requestUrl: /^http[s]?:\/\//.test(init.url) ? init.url : host + init.url,
		    			  requestData: JSON.stringify(init.params || {}),
		    			  responseData: JSON.stringify(err)
		    		  }
		    	  });
			  }
	    	  
		    	f7.hideIndicator();
		    	f7.alertMessage('连接有问题，请稍后尝试');
			})
		}

	} catch(err) {
		
	  // 如果try_catch报错，也调用errorCallback
	  if (init.errorCallback) {
		  init.errorCallback(err);
	  }
	  
	  callAppApi({
		  url: '/application/logs/appPlugins',
		  type: 'POST',
		  params: {
			  baseAppName: 'APP_USER',
			  baseUserId: loginStatus.userId || '',
			  baseOrderId: init.orderId || '',
			  pluginTag: 'callAppApi_tryCatch_errorCallback',
			  requestUrl: /^http[s]?:\/\//.test(init.url) ? init.url : host + init.url,
			  requestData: JSON.stringify(init.params || {}),
			  responseData: JSON.stringify(err)
		  }
	  });
		
		f7.hideIndicator();
		f7.alertMessage('连接有问题，请稍后尝试');
	}
  };
  
  return {
	callAppApiNew: callAppApiNew
  };
});