define([
  'js/config',
  'jquery',
  'js/lib/pawebjs',
  'js/datas'
], function(
  config,
  $$,
  PaWebJs,
  Datas
) {
  var baseHost = config.baseHost;
  var host = config.host;
  var IV = config.IV;
  var SALT = config.SALT;
  var apptoken = config.apptoken;
  var SKIP = config.SKIP;
  var newAppVersion = JSON.parse(localStorage.getItem('version'));
  
  var dictData = Datas.dictData;
  var clickDelayTimer = Datas.clickDelayTimer;
  /**
   * @func callAppApi 封装的新ajax接口调用方式
   * @param init 可选参数
   * @param callback	回调函数
   * @returns
   */
  function callAppApi (init) {

	// 是否在请求开始时展示indicator    
	var showIndicatorStatus = typeof init.showIndicatorStatus === 'undefined' ? true : init.showIndicatorStatus;
    // 是否在请求结束时隐藏indicator
    var hideIndicatorStatus = typeof init.hideIndicatorStatus === 'undefined' ? true : init.hideIndicatorStatus;
	  
    if (showIndicatorStatus) {
    	f7.showIndicator();
    }
	
	var loginStatusStr = localStorage.getItem('loginStatus') || '';
	var loginStatus = loginStatusStr !== '' ? JSON.parse(loginStatusStr) : {};
	
	var appVersionCode = newAppVersion.appVersionCode;
	var apiVersion = newAppVersion.apiVersion;
	
    // sparta webJS
    var fp = new PaWebJs().get();
    
    if (SKIP.console_log) {
    	console.warn('********************* callAppApi 请求值 ********************* : ' + host + init.url);
    	console.log({
    	    appVersion: init.appVersionCode || appVersionCode || '',
    	    apiVersion: init.apiVersion || apiVersion || '',
    	    sessionToken: init.sessionToken || loginStatus.userSession ||'',
    	    accountId: init.accountId || loginStatus.userId || '',
    	    accountRole: init.accountLoginType || loginStatus.accountLoginType || '1',
    	    optionsMethod: init.optionsMethod || '',
    	    body: JSON.stringify(init.params || {}),
            blackBox: fp,
            blackBoxType: 'SPARTA'
    	  });
    	console.warn('************')
    	console.log(init.params || {});
    }

	// @warn: 这的ajax底层方法为 jQuery的 ajax， 其余$为Framework7.$;
	try {
		if (SKIP.cordova_http) {
			$$.ajax({
		      url: encodeURI(/^http[s]?:\/\//.test(init.url) ? init.url : host + init.url),
		      type: init.type || 'POST',
		      contentType: 'application/json',
		      timeout: 31000,
		      headers: {
		    	userId: loginStatus.userId ||'',
		    	sessionToken: init.sessionToken || loginStatus.userSession ||'',
		      },
		      data: JSON.stringify({
		        appVersion: init.appVersionCode || appVersionCode || '',
			    apiVersion: init.apiVersion || apiVersion || '',
		        sessionToken: init.sessionToken || loginStatus.userSession ||'',
		        accountId: init.accountId || loginStatus.userId || '',
		        accountRole: init.accountLoginType || loginStatus.accountLoginType || '1',
		        optionsMethod: init.optionsMethod || '',
		        body: JSON.stringify(init.params || {}),
		        // sparta参数
		        blackBox: fp,
		        blackBoxType: 'SPARTA'
		      }),
		      success: function (response) {

		    	if (SKIP.console_log) {
			    	console.warn('********************* callAppApi 返回值  ********************* : ' + host + init.url);
			    	console.log(response);
		    	}
		    	
		    	if (hideIndicatorStatus) {
		    		f7.hideIndicator();
		    	}
		    	
		    	// 旧返回值code处理方案
		    	if (response.code.length === 4) {
			        if (response.code === '2000') {
			          var responseData = response.data;
			          
			          if (responseData === null) {
			        	  responseData = {};
			          }
			          
			          if (init.successCallback) {
			            init.successCallback(responseData);
			          }
			        } else if (response.code === '4000') {
			        	
			          if (init.errorCallback) {
			        	f7.alertMessage(response.message);
			            init.errorCallback(response.message);
			          }
			        } else if (response.code === '4001') {
			        	
			        	f7.hidePreloader();
			        	
			        	f7.alertMessage(response.message);
			
			        	logout();
			        	
			        	if (init.logoutCallback) {
			        		init.logoutCallback(response.message);
			        	}
			        } else if (response.code === '4002') {
			        	f7.alertMessage(response.message);
			        	
			        	var timeLink = setTimeout(function() {
//			        		mainView.loadPage('index.html');
			    			mainView.router.load({
			    				url: 'index.html',
			    				animatePages: false
			    			});
			        		
			        		clearTimeout(timeLink);
			        	}, 3000);
			        }
		    	} else if (response.code.length === 8) {
		    		// 员工购 与 其他业务类型 下单区别判断
		    		if (init.params.baseBusinessType && init.params.baseBusinessType == '005001') {	// 如果有业务类型并且为员工购业务类型
		    			if (response.code === '14508000') {									// 如果存在一个员工购的订单
		    				dealWithErrorCode();											// 弹出错误提示框
		    			} else {															// 如果存在其他业务类型订单
		    				dealWithSuccessCode();											// 走可以下单逻辑
		    			}
		    		} else {																// 业务类型不为员工购
			    		// 新返回值code处理方案
			    		if (response.code.slice(-1) === '1') {								// 如果返回code为1结尾，说明可以下单，继续下单
			    			dealWithSuccessCode();											// 继续下单逻辑
			    		} else if (response.code.slice(-1) === '0') {						// 如果返回code为0结尾，说明存在一个订单
			    			// 如果存在一个员工购订单 || 如果存在一个成人教育订单
			    			// 如果存在一个家装线上化订单，通过8位code走成功回调， 特殊处理
			    			if (response.code === '14508000' || response.code === '14507600' || response.code === '14506100' || response.code === '14506000') {								
			    				dealWithSuccessCode();										// 继续下单逻辑
			    			} else {														// 如果存在的不是员工购订单
			    				dealWithErrorCode();										// 如果存在的不是员工购订单，则判断码表弹出提示框
			    			}
			    		}
		    		}

		    		function dealWithSuccessCode() {
		    			if (response.code === '14201001') {
		    				var timeoutOrder = setTimeout(function() {
			    				mainView.router.load({
			    					url: 'order.html'
			    				});
			    				clearTimeout(timeoutOrder);
		    				}, 1000);
		    			} else if (response.code === '14301001') {
		    				var timeoutOrderDetail = setTimeout(function() {
		            	        mainView.router.load({
									url: 'orderDetail.html',
									query: {
									    orderId: response.data.baseOrderId,
									    baseBusinessType: response.data.baseBusinessType
									}
		          		        });
		            	        clearTimeout(timeoutOrderDetail);
		    				}, 1000);
		    			} else {
		    				if (init.successCallback) {
			    				init.successCallback(response)
			    			}
		    			}
		    		}
		    		
		    		function dealWithErrorCode() {
		    			if (init.errorCallback) {
		    				
		    				var alertMessageText = '';
							// 这里接口返回新的码表配置信息
							dictData.message.forEach(function(item) {
								if (item.dictSerialNo === response.code) {
									alertMessageText = item.dictValue;
								}
							});
							
							f7.alertMessage(alertMessageText);
		    				
		    				init.errorCallback(response);
		    			}
		    		}
		    	}
		      },
		      error: function (err) {
		    	  if (init.errorCallback) {
		    		  init.errorCallback(err);
			    	  callAppApi({
			    		  url: '/application/logs/appPlugins',
			    		  type: 'POST',
			    		  params: {
			    			  baseAppName: 'APP_USER',
			    			  baseUserId: loginStatus.userId || '',
			    			  baseOrderId: init.orderId || '',
			    			  pluginTag: 'callAppApi_jqueryAjax_errorCallback',
			    			  requestUrl: /^http[s]?:\/\//.test(init.url) ? init.url : host + init.url,
			    			  requestData: JSON.stringify(init.params || {}),
			    			  responseData: JSON.stringify(err)
			    		  }
			    	  });
		    	  }
		    	  
		    	  f7.hideIndicator();
		    	  f7.alertMessage('连接有问题，请稍后尝试');
		      },
		      complete: function (response) {
		    	  if (hideIndicatorStatus) {
		    		  f7.hideIndicator();
		    	  }
		    	  if (init.completeCallback) {
		    		  init.completeCallback(response.responseJSON);
		    	  }
		      }
		    });
		} else {
			var reqUrl = /^http[s]?:\/\//.test(init.url) ? init.url : host + init.url;
			var reqParam = {
		        appVersion: init.appVersionCode || appVersionCode || '',
			    apiVersion: init.apiVersion || apiVersion || '',
		        sessionToken: init.sessionToken || loginStatus.userSession ||'',
		        accountId: init.accountId || loginStatus.userId || '',
		        accountRole: init.accountLoginType || loginStatus.accountLoginType || '1',
		        optionsMethod: init.optionsMethod || '',
		        body: JSON.stringify(init.params || {}),
		        // sparta参数
		        blackBox: fp,
		        blackBoxType: 'SPARTA'
		    }
			
			cordovaHTTP.setHeader("userId", loginStatus.userId ||'');
			cordovaHTTP.setHeader("sessionToken", init.sessionToken || loginStatus.userSession ||'');
			
			cordovaHTTP.postJson(encodeURI(reqUrl), reqParam, {}, function(res) {
				
				var response = JSON.parse(res.data);
				
		    	if (hideIndicatorStatus) {
		    		f7.hideIndicator();
		    	}
		    	
		    	// 旧返回值code处理方案
		    	if (response.code.length === 4) {
			        if (response.code === '2000') {
			          var responseData = response.data;
			          
			          if (responseData === null) {
			        	  responseData = {};
			          }
			          
			          if (init.successCallback) {
			            init.successCallback(responseData);
			          }
			        } else if (response.code === '4000') {
			        	
			          if (init.errorCallback) {
			        	f7.alertMessage(response.message);
			            init.errorCallback(response.message);
			          }
			        } else if (response.code === '4001') {
			        	
			        	f7.hidePreloader();
			        	
			        	f7.alertMessage(response.message);
			
			        	logout();
			        	
			        	if (init.logoutCallback) {
			        		init.logoutCallback(response.message);
			        	}
			        } else if (response.code === '4002') {
			        	f7.alertMessage(response.message);
			        	
			        	var timeLink = setTimeout(function() {
//			        		mainView.loadPage('index.html');
			    			mainView.router.load({
			    				url: 'index.html',
			    				animatePages: false
			    			});
			        		
			        		clearTimeout(timeLink);
			        	}, 3000);
			        }
		    	} else if (response.code.length === 8) {
		    		// 员工购 与 其他业务类型 下单区别判断
		    		if (init.params.baseBusinessType && init.params.baseBusinessType == '005001') {	// 如果有业务类型并且为员工购业务类型
		    			if (response.code === '14508000') {									// 如果存在一个员工购的订单
		    				dealWithErrorCode();											// 弹出错误提示框
		    			} else {															// 如果存在其他业务类型订单
		    				dealWithSuccessCode();											// 走可以下单逻辑
		    			}
		    		} else {																// 业务类型不为员工购
			    		// 新返回值code处理方案
			    		if (response.code.slice(-1) === '1') {								// 如果返回code为1结尾，说明可以下单，继续下单
			    			dealWithSuccessCode();											// 继续下单逻辑
			    		} else if (response.code.slice(-1) === '0') {						// 如果返回code为0结尾，说明存在一个订单
			    			// 如果存在一个员工购订单 || 如果存在一个成人教育订单
			    			// 如果存在一个家装线上化订单，通过8位code走成功回调， 特殊处理
			    			if (response.code === '14508000' || response.code === '14507600' || response.code === '14506100' || response.code == '14506000') {								
			    				dealWithSuccessCode();										// 继续下单逻辑
			    			} else {														// 如果存在的不是员工购订单
			    				dealWithErrorCode();										// 如果存在的不是员工购订单，则判断码表弹出提示框
			    			}
			    		}
		    		}

		    		function dealWithSuccessCode() {
		    			if (response.code === '14201001') {
		    				var timeoutOrder = setTimeout(function() {
			    				mainView.router.load({
			    					url: 'order.html'
			    				});
			    				clearTimeout(timeoutOrder);
		    				}, 1000);
		    			} else if (response.code === '14301001') {
		    				var timeoutOrderDetail = setTimeout(function() {
		    					localStorage.removeItem('showinfoTip_' + loginStatus.userId);
		            	        mainView.router.load({
									url: 'orderDetail.html',
									query: {
									    orderId: response.data.baseOrderId,
									    baseBusinessType: response.data.baseBusinessType
									}
		          		        });
		            	        clearTimeout(timeoutOrderDetail);
		    				}, 1000);
		    			} else {
		    				if (init.successCallback) {
			    				init.successCallback(response)
			    			}
		    			}
		    		}
		    		
		    		function dealWithErrorCode() {
		    			if (init.errorCallback) {
		    				
		    				var alertMessageText = '';
							// 这里接口返回新的码表配置信息
							dictData.message.forEach(function(item) {
								if (item.dictSerialNo === response.code) {
									alertMessageText = item.dictValue;
								}
							});
							
							f7.alertMessage(alertMessageText);
		    				
		    				init.errorCallback(response);
		    			}
		    		}
		    	}
			}, function(err) {
			 
		      // 如果进入错误回调函数，则调用errorCallback
			  if (init.errorCallback) {
				  init.errorCallback(err);
				  
		    	  callAppApi({
		    		  url: '/application/logs/appPlugins',
		    		  type: 'POST',
		    		  params: {
		    			  baseAppName: 'APP_USER',
		    			  baseUserId: loginStatus.userId || '',
		    			  baseOrderId: init.orderId || '',
		    			  pluginTag: 'callAppApi_cordovaHTTP_errorCallback',
		    			  requestUrl: /^http[s]?:\/\//.test(init.url) ? init.url : host + init.url,
		    			  requestData: JSON.stringify(init.params || {}),
		    			  responseData: JSON.stringify(err)
		    		  }
		    	  });
			  }
	    	  
		    	f7.hideIndicator();
		    	f7.alertMessage('连接有问题，请稍后尝试');
			})
		}

	} catch(err) {
		
	  // 如果try_catch报错，也调用errorCallback
	  if (init.errorCallback) {
		  init.errorCallback(err);
	  }
	  
	  callAppApi({
		  url: '/application/logs/appPlugins',
		  type: 'POST',
		  params: {
			  baseAppName: 'APP_USER',
			  baseUserId: loginStatus.userId || '',
			  baseOrderId: init.orderId || '',
			  pluginTag: 'callAppApi_tryCatch_errorCallback',
			  requestUrl: /^http[s]?:\/\//.test(init.url) ? init.url : host + init.url,
			  requestData: JSON.stringify(init.params || {}),
			  responseData: JSON.stringify(err)
		  }
	  });
		
		f7.hideIndicator();
		f7.alertMessage('连接有问题，请稍后尝试');
	}
  };
  
  /**
   * @func callWebHtml 封装的新ajax接口调用方式
   * @param init 可选参数
   * @param callback	回调函数
   * @returns
   */
  function callWebHtml (init) {

	// 是否在请求开始时展示indicator    
	var showIndicatorStatus = typeof init.showIndicatorStatus === 'undefined' ? true : init.showIndicatorStatus;
    // 是否在请求结束时隐藏indicator
    var hideIndicatorStatus = typeof init.hideIndicatorStatus === 'undefined' ? true : init.hideIndicatorStatus;
	  
    if (showIndicatorStatus) {
    	f7.showIndicator();
    }
	
	var loginStatusStr = localStorage.getItem('loginStatus') || '';
	var loginStatus = loginStatusStr !== '' ? JSON.parse(loginStatusStr) : {};
	
	var appVersionCode = newAppVersion.appVersionCode;
	var apiVersion = newAppVersion.apiVersion;
	
    // sparta webJS
    var fp = new PaWebJs().get();
    
    try {
    	if (SKIP.cordova_http) {
    		$$.ajax({
		      url: encodeURI(/^http[s]?:\/\//.test(init.url) ? init.url : host + init.url),
		      type: init.type || 'POST',
		      contentType: 'application/json',
		      timeout: 31000,
		      headers: {
		    	userId: loginStatus.userId ||'',
		    	sessionToken: init.sessionToken || loginStatus.userSession ||'',
		      },
		      data: JSON.stringify({
		        appVersion: init.appVersionCode || appVersionCode || '',
			    apiVersion: init.apiVersion || apiVersion || '',
		        sessionToken: init.sessionToken || loginStatus.userSession ||'',
		        accountId: init.accountId || loginStatus.userId || '',
		        accountRole: init.accountLoginType || loginStatus.accountLoginType || '1',
		        optionsMethod: init.optionsMethod || '',
		        body: JSON.stringify(init.params || {}),
		        // sparta参数
		        blackBox: fp,
		        blackBoxType: 'SPARTA'
		      }),
		      success: function(response) {
			      if (hideIndicatorStatus) {
				      f7.hideIndicator();
				  }
			      
		          if (init.successCallback) {
			          init.successCallback(response);
			      }
		      },
		      error: function(err) {
		    	  
					callAppApi({
						url: host + '/application/logs/appPlugins',
						type: 'POST',
						params: {
							baseAppName: 'APP_USER',
							baseUserId: loginStatus.userId || '',
							baseOrderId: init.orderId || '',
							pluginTag: 'callWebHtml_jqueryAjax_errorCallback',
							requestUrl: /^http[s]?:\/\//.test(init.url) ? init.url : host + init.url,
							requestData: JSON.stringify(init.params || {}),
							responseData: JSON.stringify(err)
						}
					})
		    	  
		    	  f7.hideIndicator();
		    	  f7.alertMessage('连接有问题，请稍后尝试');
		      },
		      complete: function (response) {
		    	  if (hideIndicatorStatus) {
		    		  f7.hideIndicator();
		    	  }
		    	  if (init.completeCallback) {
		    		  init.completeCallback(response);
		    	  }
		      }
			});
    	} else {
			var reqUrl = /^http[s]?:\/\//.test(init.url) ? init.url : host + init.url;
			var reqParam = {
		        appVersion: init.appVersionCode || appVersionCode || '',
			    apiVersion: init.apiVersion || apiVersion || '',
		        sessionToken: init.sessionToken || loginStatus.userSession ||'',
		        accountId: init.accountId || loginStatus.userId || '',
		        accountRole: init.accountLoginType || loginStatus.accountLoginType || '1',
		        optionsMethod: init.optionsMethod || '',
		        body: JSON.stringify(init.params || {}),
		        // sparta参数
		        blackBox: fp,
		        blackBoxType: 'SPARTA'
		    }
			
			cordovaHTTP.setHeader("userId", loginStatus.userId ||'');
			cordovaHTTP.setHeader("sessionToken", init.sessionToken || loginStatus.userSession ||'');
			
			cordovaHTTP.postJson(encodeURI(reqUrl), reqParam, {}, function(res) {
				
//				var response = JSON.parse(res.data);
				var response = res.data;
				
		    	if (hideIndicatorStatus) {
		    		f7.hideIndicator();
		    	}

		    	if (init.successCallback) {
		    		init.successCallback(response);
		    	}
		    	
			}, function(err) {
				
				callAppApi({
					url: host + '/application/logs/appPlugins',
					type: 'POST',
					params: {
						baseAppName: 'APP_USER',
						baseUserId: loginStatus.userId || '',
						baseOrderId: init.orderId || '',
						pluginTag: 'callWebHtml_cordovaHTTP_errorCallback',
						requestUrl: /^http[s]?:\/\//.test(init.url) ? init.url : host + init.url,
						requestData: JSON.stringify(init.params || {}),
						responseData: JSON.stringify(err)
					}
				});
				
		    	f7.hideIndicator();
		    	f7.alertMessage('连接有问题，请稍后尝试');
			})
    	}

	} catch(err) {
		
		  callAppApi({
			  url: '/application/logs/appPlugins',
			  type: 'POST',
			  params: {
				  baseAppName: 'APP_USER',
				  baseUserId: loginStatus.userId || '',
				  baseOrderId: init.orderId || '',
				  pluginTag: 'callAppApi_tryCatch_errorCallback',
				  requestUrl: /^http[s]?:\/\//.test(init.url) ? init.url : host + init.url,
				  requestData: JSON.stringify(init.params || {}),
				  responseData: JSON.stringify(err)
			  }
		  });
		
		f7.hideIndicator();
		f7.alertMessage('连接有问题，请稍后尝试');
	}
  }
  
  function isOwnEmpty(obj) {
	  for (var name in obj) {
		
		  if (obj.hasOwnProperty(name)) {
			  return false;
		  }
	  }
	  
	  return true;
  }
  
  function isEmpty(obj) {
	  for (var name in obj) {
		  return false;
	  }
	  
	  return true;
  }

  function isEmptyArr(arr) {
	  
	  if (Object.prototype.toString.call(arr) === '[object Array]' && arr.length === 0) {
		  return true;
	  } else {
		  return false;
	  }
  }
  
  // 退出登陆
  function logout() {
  	var loginStatus = JSON.parse(localStorage.getItem('loginStatus'));
	callAppApi({
		url: '/app/logout',
		type: 'POST',
		params: {
			accountName : loginStatus.accountName,
  			userSession: loginStatus.userSession
  		},
		successCallback: function(data) {
			localStorage.setItem('loginStatus', JSON.stringify({
			  userId: '',
			  oldId: '',
			  userSession: '',
			  accountName: '',
			  accountLoginType: '',
			  orderList: [],
			  oldUser: false
			}));
			
			localStorage.setItem('authStep1Data', '');
			localStorage.setItem('authStep2Data', '');

			var timeA = setTimeout(function() {
				f7.showToolbar('#toolbar');
				mainView.loadPage('login.html');
			}, 1000);
		}
	})
  }

  // 获取设备信息
  function getDeviceType() {
	var deviceType = '';
	var ua = navigator.userAgent.toLowerCase();
	
	if (/iphone|ipad|ipod/.test(ua)) {
		deviceType = 'IOS';
	} else if (/android/.test(ua)) {
		deviceType = 'ANDROID';
	} else {
		// 默认值为'ANDROID', 后端默认值为'ANDROID'
		deviceType = 'ANDROID';
	}
	
	return deviceType;
  }

  // 倒计时
  function countDown(selector, sec, title) {
	var count = sec;
	
	var timeCount = setInterval(function() {
		$(selector).attr('disabled', true);
		if (count > 0) {
			count--;
			$(selector).text(count + 's');
		} else if (count <= 1) {
			$(selector).removeAttr('disabled');
			$(selector).text(title);
			clearInterval(timeCount);
		}
	}, 1000);
	return timeCount;
  }

  function getParameterByName(name) {
	    name = name.replace(/[\[]/, "\\\[").replace(/[\]]/, "\\\]");
	    var regexS = "[\\?&]" + name + "=([^&#]*)";
	    var regex = new RegExp(regexS);
	    var results = regex.exec(window.location.search);
	    if (results == null)
	        return "";
	    else
	        return decodeURIComponent(results[1].replace(/\+/g, " "));
	};
	
  function getFormatDate(dateStr) {
	  var localDate = new Date(dateStr);
	  
      var year = localDate.getFullYear();
      var month = localDate.getMonth() + 1 < 10 ? '0' + (localDate.getMonth() + 1) : localDate.getMonth() + 1;
      var date = localDate.getDate() < 10 ? '0' + localDate.getDate() : localDate.getDate();
      var hour = localDate.getHours() < 10 ? '0' + localDate.getHours() : localDate.getHours();
      var min = localDate.getMinutes() < 10 ? '0' + localDate.getMinutes() : localDate.getMinutes();
      var sec = localDate.getSeconds() < 10 ? '0' + localDate.getSeconds() : localDate.getSeconds();
      var millisec = localDate.getMilliseconds();
      
      var formatDate = year + '-' + month + '-' + date + ' ' + hour + ':' + min + ':' + sec + ' ' + millisec;
      
      return formatDate;
  }
  	
  	function getFormatPrice(priceStr) {
  		if (/^[0-9]+$/.test(priceStr)) {
  			return priceStr + '.00';
  		} else if (/^[0-9]+\.[0-9]{1}$/.test(priceStr)) {
  			return priceStr + '0';
  		} else if (/^[0-9]+\.[0-9]{2}$/.test(priceStr)) {
  			return priceStr;
  		} else {
  			return priceStr;
  		}
  	}
  
	//获取当前日期
	function getDay() {
		var currentdate = getFormatDate(new Date()).substring(0,10);
		return currentdate;
	}
	
	// 格式化价格显示
	function formatPrice(priceStr) {
		if (/\.0$/.test(priceStr)) {
			return priceStr.slice(0, -2);
		} else if (/\.00$/.test(priceStr)) {
			return priceStr.slice(0, -3);
		} else {
			return priceStr;
		}
	}

	// 经纬度信息
	function getLngAndLat(successCallback, errorCallback) {
		
		if (!SKIP.cordova_lngAndLat) {
			// 获取经纬度 显示 loading框
			f7.showIndicator();

			var lng = '';
			var lat = '';
			
			var lngAndLatStatus = false;
			
			var lngAndLatTimeout = setTimeout(function() {

				if (lngAndLatStatus === false) {
					// 获取经纬度 超时隐藏 loading框
					f7.hideIndicator();
					
					// 更新状态
					lngAndLatStatus = true;
					
					successCallback({
						lng: lng,
						lat: lat
					});
					
					clearTimeout(lngAndLatTimeout);
				}
			}, 30000);
			
			navigator.geolocation.getCurrentPosition(function(position) {
				
				if (lngAndLatStatus === false) {
					var x = position.coords.longitude;
					var y = position.coords.latitude;
					
					var ggPoint = new BMap.Point(x, y);
					
					function translateCallback(data) {
						if (data.status === 0) {
							lng = data.points[0].lng;
							lat = data.points[0].lat;
						}
						
						// 获取经纬度成功隐藏 loading框
						f7.hideIndicator();
						
						// 更新状态
						lngAndLatStatus = true;
						
						successCallback({
							lng: lng,
							lat: lat
						});
					}
					
					var convertor = new BMap.Convertor();
					var pointArr = [];
					
					pointArr.push(ggPoint);
					convertor.translate(pointArr, 1, 5, translateCallback);
				}
			}, function(err) {

				if (lngAndLatStatus === false) {
					// 获取经纬度失败隐藏 loading框
					f7.hideIndicator();
					
					// 更新状态
					lngAndLatStatus = true;
					
					errorCallback(err);
				}
			});
		} else {
			successCallback({lng: '', lat: ''});
		}
	}
	//根据后台返回秒数进行倒计时
    function fillZero(n){
        return n<10? '0'+n:''+n;
    };
	
	 function formatSecondsTime(time, type) {
         var times = parseInt(time);
         var days = 0;
         var hours = 0;
         var minutes = 0;
         var seconds = 0;

         if (type == 'sec'){
            times = times;
         }else if (type == 'miliSec') {
            times = times / 1000;
         }

        if (times > 86400 ) {//天数
                days = Math.floor(times / (24 * 60 * 60));
                hours = Math.floor(times / (60 * 60) % 24);
                minutes = Math.floor(times / 60 % 60);
                seconds = Math.floor(times % 60);
            }
            else if (times > 3600 ) {//小时数
                days = 0;
                hours = Math.floor(times / (60 * 60));
                minutes = Math.floor(times / 60 % 60);
                seconds = Math.floor(times % 60);
            }else if (times > 60 ){//分钟数
                days = 0;
                hours = 0;
                minutes = Math.floor(times / 60 % 60);
                seconds = Math.floor(times % 60);
            }else if (times > 0 ) {
                days = 0;
                hours = 0;
                minutes = 0;
                seconds = times;
            }
        return {
            days: fillZero(days),
            hours: fillZero(hours),
            minutes: fillZero(minutes),
            seconds: fillZero(seconds)
        }
    }
	
	/** 
	 * 图形验证码
	 * @param options 
	 * 		  {
	 * 			  imgId:		临时图片id  				必传
	 * 			  canvasId: 	画布id					必传
	 * 		  }
	 * @param successCallback
	 * @param errorCallback
	 * @returns
	 */
	function renderVerifyImgCode(options) {
		
		var deviceInfo = '';
		if (!SKIP.cordova_uuid) {
			deviceInfo = device.uuid;
		}
		
		if (!options.imgSelector) { alert('请传入临时图片id'); return; }
		if (!options.canvasSelector) { alert('请传入canvasId'); return; }
		
		callAppApi({
			url: '/application/verify/code',
			type: 'POST',
			params: {
				baseBusinessType: '',
				deviceId: deviceInfo || 'defaultDeviceId',
				verifyCodeWidth: 200,
				verifyCodeHeight: options.canvasHeight || 48
			},
			successCallback: function(codeRes) {
				
				var verifyCodeImgElem = document.querySelector(options.imgSelector);
				var verifyCodeImgCanvas = document.querySelector(options.canvasSelector);
				var verifyCodeImgCtx = verifyCodeImgCanvas.getContext('2d');
				
				verifyCodeImgElem.onload = function() {
					verifyCodeImgCtx.drawImage(verifyCodeImgElem, 0, 0, 200, options.canvasHeight || 48, 0, 0, $$(verifyCodeImgCanvas).width() * 2, $$(verifyCodeImgCanvas).height() * 2);
				};
				verifyCodeImgElem.src = "data:image/png;base64," + codeRes.verifyCodeValue;
				
				if (options.successCallback) {
					options.successCallback(codeRes);
				}
				
			},
			errorCallback: function(err) {
				if (options.errorCallback) { options.errorCallback(err); }
			}
		})
	}
	/**
	 * 防止连续点击
	 */
	var clickDelay = function(id, fn, time) {
		if (typeof time == 'undefined') {
			time = 1000;
		}
		if (clickDelayTimer[id]) {
	        window.clearTimeout(clickDelayTimer[id]);
	        delete clickDelayTimer[id];
	    }
	    return clickDelayTimer[id] = window.setTimeout(function () {
	        fn();
	        delete clickDelayTimer[id];
	    }, time)
	}
/**
 * 旧模块代码
 */
	
	var crckey = getParameterByName("crckey");
	
	var aesUtil = new AesUtil(128, 1);
	function encrypt(s, c) {
	    return aesUtil.encrypt(SALT, IV, c, s);
	}
	
	function decrypt(s, c) {
	    return aesUtil.decrypt(SALT, IV, c, s);
	}
  
  
  function setParam(key, value) {
	  return '"' + key + '":"' + value + '"';
  }
  
  function callAction(sObject, sAction, sParam, func, p1, p2, p3, p4, p5, p6, p7, p8) {

	  var loginStatus = JSON.parse(localStorage.getItem('loginStatus'));
	  	
	    var sPost = '{"_c":"' + crckey + '","_u":"' + loginStatus.userId + '","a":"' + sObject + '","c":"' + sAction + '"';
	    if (sParam) {
	        sPost += ',' + sParam;
	    }
	    sPost += '}';
	    
	    var defaultUserSession = loginStatus.userSession || '';
	    
	    $$.ajax({
	    	url: baseHost + '/app/do',
            method: 'POST',
            async: true,
            cache: false,
            timeout: 30000,
            data: {
                a: encrypt(sPost, defaultUserSession),
                b: "",
                c: defaultUserSession
            },
            success: function(data) {
            	console.log(data);
                try {
                    var a = eval("(" + decrypt(data, defaultUserSession) + ");");
                    
                    if (a.m) {
                        f7.alert(a.m);
                    }
                    if (a.c) {
                        eval(a.c);
                    }
                    if (a.s == '1') {
                        if (func) {
                            func(a, p1, p2, p3, p4, p5, p6, p7, p8);
                        }
                    }
                } catch (e) {
                	
                }
            }
            
	    });
  }
  
  /**
   * @description
   * 	creditStatus 额度状态
   * 		0-参考1
   *        1-无额度，即未申请过额度
   *        2-申请未通过且在禁闭期
   *        3-申请未通过且非禁闭期
   *        4-额度申请通过状态有效(只能下单)
   *        5-额度申请通过状态失效，即已经超过有效期
   * 		6-审核中 - 对应授信501回退, 取消订单再下单
   *        
   *     auditInfoStatus APP端授信流程状态:
   *        信息驳回:XX1 信息通过:XX2
   *        基本信息
   *            用户信息-提交: 110 
   *            工作信息-提交: 120 
   *            联系人信息-提交: 130
   *        身份认证信息
   *            人脸识别信息-提交: 210
   *            身份证信息-提交: 220
   *            手持身份证信息-提交: 230
   * 
   *        专案信息
   *            专案基本信息: 310
   *            专案补充信息: 320
   *        业务资料信息
   *            业务资料信息-提交: 410
   *        信审结果
   *            审核回退: 501
   *            审核通过: 502
   * 
   * @param {string} typeCode - 业务类型
   * @param {object} options - 参数对象, 格式如下
   * 					{
							query:{
								fromPage: 'index'
							}
						}
   * @param {string} options.fromPage - 跳转来源
   * @param {function} cbFn  - 页面跳转方法
   * 
   */

  function infoQueryRouter(typeCode, options, cbFn) {
      var loginStatus = JSON.parse(localStorage.getItem('loginStatus'));
      
      callAppApi({
          url: '/app/credit/audit/infoQuery',
          type: 'POST',
          params: {
              userId: loginStatus.userId,
              baseBusinessType: typeCode
          },
          successCallback: function(res) {
              var creditStatus = res.creditStatus;
			  var auditInfoStatus = res.auditInfoStatus;
		      var orderId = res.baseOrderId;
			  var orderStatus = res.orderStatus;
			  
			  options.query.res = res; 	  
              
              if (typeCode === '004003') {
					if (creditStatus === '0' || creditStatus === '1' || creditStatus === '3' || creditStatus === '5') {
						cbFn('authentication', options);
					} else if (creditStatus === '2') {
						f7.alert('很抱歉，您暂时无法办理该业务，感谢关注！');
					} else if (creditStatus === '4') {//反欺诈通过状态值为4
						/**
						 * 1.判断订单orderId
						 */
						if(orderId){//orderId不为空
							// 家装线上化业务线，创建订单之后状态为12 -> 13 -> 20， 废弃
							//订单状态修改 11-17，创建订单：10； 更新家装信息后12；提交审核或回退提交后为13；信审平台回退为15；信审平台通过20；信审平台拒绝58
							if(orderStatus == '10'){//跳转到业务资料页1
								cbFn('materialUpload', options);//跳转到业务资料页
							}else if(orderStatus == '12'){//跳转到业务资料页2或是订单页
								if(auditInfoStatus == '330'){
									cbFn('uploadEvidence', options);//跳转到授信资料页
								}else if(auditInfoStatus == '410'){
									mainView.router.load({
										url: 'orderDetail.html',
										query: {
											baseBusinessType: typeCode,
											orderId: orderId,
											fromPage: options.query.fromPage
										}
									});
								}
							}else{
								mainView.router.load({
									url: 'orderDetail.html',
									query: {
										baseBusinessType: typeCode,
										orderId: orderId,
										fromPage: options.query.fromPage
									}
								});
							}
							
						}else{ //orderId为空
							 if (auditInfoStatus.slice(0,1) === '1') { //反欺诈信息已提交
								cbFn('uploadIdCard', options);// 跳转到身份识别
							 }else{
								cbFn('chooseGoods', options);//选品页
							 } 
							
						}

					} else if (creditStatus === '6') { // creditStatus -> orderId -> orderStatus
						// if (auditInfoStatus === '501' || auditInfoStatus === '410') {
							if(orderId){ // 有订单
								if(orderStatus == '10'){ // 新建订单
									cbFn('materialUpload', options);//跳转到业务资料页
								}else{ //12-更新订单， 13-提交审核或回退提交 15- 回退订单等状态
									mainView.router.load({
										url: 'orderDetail.html',
										query: {
											baseBusinessType: typeCode,
											orderId: orderId,
											fromPage: options.query.fromPage
										}
									});
								}
								
							}else{ //选品下单
								cbFn('chooseGoods', options);//选品页
							}
							
					}
				} else if (typeCode === '003002') {
	                  if (creditStatus === '0' || creditStatus === '1' || creditStatus === '3' || creditStatus === '5') {
	                      cbFn('chooseProfession', {
	                          query: {
	                              fromPage: 'index',
	                              adultCreditRes: res
	                          }
	                      });
	                  } else if (creditStatus === '2') {
	                      f7.alertMessage('很抱歉，您暂时无法办理该业务，感谢关注！');
	                  } else if (creditStatus === '4') {
	                      /**
	                       * 1.判断订单orderId
	                       */
	                      if (orderId){//orderId不为空
	                          
	                          if (orderStatus == '10') {
	                              if (auditInfoStatus.slice(0, 1) === '2') {
	                            	  var skipBindBankcardStatus = localStorage.getItem('adultEducationSkipBindBankcard_' + orderId) == '1' ? false : true;
	                            	  
	                            	  if (skipBindBankcardStatus == true) {
	                            		  cbFn('uploadEvidence', options);
	                            	  } else if (skipBindBankcardStatus == false) {
	                            		  mainView.router.load({
	                            			  url: 'bindBankcard.html',
	                            			  query: {
	                            				  baseBusinessType: typeCode,
	                            				  orderId: orderId,
	                            				  fromPage: 'adultEducationChooseGoods'
	                            			  }
	                            		  })
	                            	  }
	                              } else {
	                                    mainView.router.load({
	                                        url: 'orderDetail.html',
	                                        query: {
	                                            baseBusinessType: typeCode,
	                                            orderId: orderId,
	                                            fromPage: options.query.fromPage
	                                        }
	                                    }); 
	                              }
	                          } else {
	                              mainView.router.load({
	                                  url: 'orderDetail.html',
	                                  query: {
	                                      baseBusinessType: typeCode,
	                                      orderId: orderId,
	                                      fromPage: options.query.fromPage
	                                  }
	                              });
	                          }

	                      } else {
	                          if (auditInfoStatus.slice(0, 1) === '1') {     //反欺诈信息已提交
	                              cbFn('uploadIdCard', options);
	                          } else {
	                              cbFn('chooseGoods', options);//选品页
	                          }
	                      }
	                  } else if (creditStatus === '6') {
                            if(orderId){
                                mainView.router.load({
                                    url: 'orderDetail.html',
                                    query: {
                                        baseBusinessType: typeCode,
                                        orderId: orderId,
                                        fromPage: options.query.fromPage
                                    }
                                });
                            }else{
                                cbFn('chooseGoods', options);//选品页
                            }
	                  }
	              } else if (typeCode === '003001') {
	                  if (creditStatus === '0' || creditStatus === '1' || creditStatus === '3' || creditStatus === '5') {
                          loadAdultEducationPage('chooseProfession', {
                              query: {
                                  fromPage: 'index',
                                  adultCreditRes: res
                              }
                          });
                      } else if (creditStatus === '2') {
                          f7.alertMessage('很抱歉，您暂时无法办理该业务，感谢关注！');
                      } else if (creditStatus === '4') {
                          /**
                           * 1.判断订单orderId
                           */
                          if (orderId){//orderId不为空
                              
                              if (orderStatus == '10') {
                                  if (auditInfoStatus.slice(0, 1) === '1') {
                                      cbFn('checkFace', options);
                                  } else if (auditInfoStatus.slice(0, 1) === '2') {
                                      cbFn('checkInfo', options);
                                  } else {
                                      mainView.router.load({
                                          url: 'orderDetail.html',
                                          query: {
                                              baseBusinessType: typeCode,
                                              orderId: orderId,
                                              fromPage: options.query.fromPage
                                          }
                                      }); 
                                  }
                              } else if (orderStatus === '11' || orderStatus === '12') {
                                  if (auditInfoStatus.slice(0, 1) === '1' || auditInfoStatus.slice(0, 1) === '2') {
                                      cbFn('checkInfo', options);
                                  } else {
                                      mainView.router.load({
                                          url: 'orderDetail.html',
                                          query: {
                                              baseBusinessType: typeCode,
                                              orderId: orderId,
                                              fromPage: options.query.fromPage
                                          }
                                      }); 
                                  }
                              } else {
                                  mainView.router.load({
                                      url: 'orderDetail.html',
                                      query: {
                                          baseBusinessType: typeCode,
                                          orderId: orderId,
                                          fromPage: options.query.fromPage
                                      }
                                  });
                              }
                              
                          } else {
                              cbFn('chooseGoods', options);//选品页
                          }
                      } else if (creditStatus === '6') {
                            if(orderId){
                                mainView.router.load({
                                    url: 'orderDetail.html',
                                    query: {
                                        baseBusinessType: typeCode,
                                        orderId: orderId,
                                        fromPage: options.query.fromPage
                                    }
                                });
                            }else{
                                cbFn('chooseGoods', options);//选品页
                            }
                      }
	              }
					
			  }
          })
  }
  
  /**
   * 浮点化字符串金额
   */
   function moneyStrToFloat(money) {
       if (!/^[0-9]+(.[0-9]{2})?$/.test(money)) {
                alert('请传入正确的字符串金额');
       }
         
       return parseFloat(money);
   }
   
   function getDeviceSimulator() {
	   var deviceIsSim = '';
	   if (!SKIP.cordova_isVirtual) {
		   if (device.isVirtual === true) {
			   deviceIsSim = '1';
		   } else {
			   deviceIsSim = '0';
		   }
	   } else {
		   deviceIsSim = '';
	   }
	   
	   return deviceIsSim
   }
  
  return {
	callAppApi: callAppApi,
	callWebHtml: callWebHtml,
	isOwnEmpty: isOwnEmpty,
	isEmpty: isEmpty,
	isEmptyArr: isEmptyArr,
	getDeviceType: getDeviceType,
	countDown: countDown,
	logout: logout,
	getFormatDate: getFormatDate,
	getFormatPrice: getFormatPrice,
	renderVerifyImgCode: renderVerifyImgCode,								// 请求图片验证码
	clickDelay: clickDelay, 
	
	getLngAndLat: getLngAndLat,
	
	callAction: callAction,
	setParam: setParam,
	getDay: getDay,
	formatPrice: formatPrice,
	formatSecondsTime:formatSecondsTime,
	
	moneyStrToFloat: moneyStrToFloat,

	infoQueryRouter: infoQueryRouter, // 初始化路由跳转判断
	
	getDeviceSimulator: getDeviceSimulator
  };
});